// COM proxy class, output from FunctionList.js
package owapi;
/**
 * 1-Wire Humidity interface class for basic Humidity measuring
 * operations. This class should be implemented for each Humidity
 * type 1-Wire device.
 *
 *
 * <P>The HumidityContainer methods can be organized into the following categories: </P>
 * <UL>
 *   <LI> <B> Information </B>
 *     <UL>
 *       <LI> {@link #getHumidity                        getHumidity}
 *       <LI> {@link #getHumidityResolution              getHumidityResolution}
 *       <LI> {@link #getHumidityAlarm                   getHumidityAlarm}
 *       <LI> {@link #getHumidityAlarmResolution         getHumidityAlarmResolution}
 *       <LI> {@link #getHumidityResolution              getHumidityResolution}
 *       <LI> {@link #getHumidityResolutions             getHumidityResolutions}
 *       <LI> {@link #hasSelectableHumidityResolution    hasSelectableHumidityResolution}
 *       <LI> {@link #hasHumidityAlarms                  hasHumidityAlarms}
 *       <LI> {@link #isRelative                         isRelative}
 *     </UL>
 *   <LI> <B> Options </B>
 *     <UL>
 *       <LI> {@link #doHumidityConvert     doHumidityConvert}
 *       <LI> {@link #setHumidityAlarm      setHumidityAlarm}
 *       <LI> {@link #setHumidityResolution setHumidityResolution}
 *     </UL>
 *   <LI> <B> I/O </B>
 *     <UL>
 *       <LI> {@link #readDevice  readDevice}
 *       <LI> {@link #writeDevice writeDevice}
 *     </UL>
 *  </UL>
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> <H4> Example</H4>
 * Gets humidity reading from a HumidityContainer instance '<code>hc</code>':
 * <PRE> <CODE>
 *   double lastHumidity;
 *
 *   // get the current resolution and other settings of the device (done only once)
 *   byte[] state = hc.readDevice();
 *
 *   // loop to read the humidity
 *   do 
 *   {
 *      // perform a humidity conversion
 *      hc.doHumidityConvert(state);
 *
 *      // read the result of the conversion
 *      state = hc.readDevice();
 *
 *      // extract the result out of state
 *      lastHumidity = hc.getHumidity(state);
 *      ...
 *
 *   }
 *   while (!done);
 * </CODE> </PRE>
 *
 * @see OneWireContainer28
 *
 * @version    0.00, 27 August 2001
 * @author     DS
 */
public interface HumidityContainer

{


   public static final int ALARM_HIGH
          = com.dalsemi.onewire.container.HumidityContainer.ALARM_HIGH;

   public static final int ALARM_LOW
          = com.dalsemi.onewire.container.HumidityContainer.ALARM_LOW;

   /**
    * Checks to see if humidity value given is a 'relative' humidity value.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         provides a relative humidity reading
    *
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public boolean isRelative();

   /**
    * Checks to see if this Humidity measuring device has high/low
    * trip alarms.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         has high/low trip alarms
    *
    * @see    #getHumidityAlarm
    * @see    #setHumidityAlarm
    */
   public boolean hasHumidityAlarms();

   /**
    * Checks to see if this device has selectable Humidity resolution.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         has selectable Humidity resolution
    *
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public boolean hasSelectableHumidityResolution();

   /**
    * Get an array of available Humidity resolutions in percent humidity (0 to 100).
    *
    * @return byte array of available Humidity resolutions in percent with
    *         minimum resolution as the first element and maximum resolution
    *         as the last element.
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #setHumidityResolution
    */
   public DoubleArray getHumidityResolutions();

   /**
    * Gets the Humidity alarm resolution in percent.
    *
    * @return Humidity alarm resolution in percent for this 1-wire device
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #getHumidityAlarm
    * @see    #setHumidityAlarm
    *
    */
   public double getHumidityAlarmResolution()
      throws com.dalsemi.onewire.OneWireException;

   /**
    * Performs a Humidity conversion.
    *
    * @param  state byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as 
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to 
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire 
    *         adapter
    */
   public void doHumidityConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException;

   /**
    * Gets the humidity expressed as a percent value (0.0 to 100.0) of humidity.
    *
    * @param  state byte array with device state information
    * @return humidity expressed as a percent
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #setHumidityResolution
    */
   public double getHumidity(ByteArray state);

   /**
    * Gets the current Humidity resolution in percent from the
    * <code>state</code> data retrieved from the <code>readDevice()</code>
    * method.
    *
    * @param  state byte array with device state information
    *
    * @return Humidity resolution in percent for this 1-wire device
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public double getHumidityResolution(ByteArray state);

   /**
    * Gets the specified Humidity alarm value in percent from the
    * <code>state</code> data retrieved from the
    * <code>readDevice()</code> method.
    *
    * @param  alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param  state     byte array with device state information
    *
    * @return Humidity alarm trip values in percent for this 1-wire device
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #setHumidityAlarm
    */
   public double getHumidityAlarm(int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException;

   /**
    * Sets the Humidity alarm value in percent in the provided
    * <code>state</code> data.
    * Use the method <code>writeDevice()</code> with
    * this data to finalize the change to the device.
    *
    * @param  alarmType  valid value: <code>ALARM_HIGH</code> or
    *                    <code>ALARM_LOW</code>
    * @param  alarmValue alarm trip value in percent
    * @param  state      byte array with device state information
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #getHumidityAlarm
    */
   public void setHumidityAlarm(int alarmType, double alarmValue, ByteArray state)
      throws com.dalsemi.onewire.OneWireException;

   /**
    * Sets the current Humidity resolution in percent in the provided
    * <code>state</code> data.   Use the method <code>writeDevice()</code>
    * with this data to finalize the change to the device.
    *
    * @param  resolution Humidity resolution in percent
    * @param  state      byte array with device state information
    *
    * @throws OneWireException         Device does not support selectable
    *                                  Humidity resolution
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    */
   public void setHumidityResolution(double resolution, ByteArray state)
      throws com.dalsemi.onewire.OneWireException;


}
