// COM proxy class, output from FunctionList.js
package owapi;
/**
 * 1-Wire&#174 Network path.  Large 1-Wire networks can be sub-divided into branches
 * for load, location, or organizational reasons.  Once 1-Wire devices are placed
 * on this branches there needs to be a mechanism to reach these devices.  The
 * OWPath class was designed to provide a convenient method to open and close
 * 1-Wire paths to reach remote devices.
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> <H4> Example</H4>
 * Open the path 'path' to the 1-Wire temperature device 'tc' and read the temperature:
 * <PRE> <CODE>
 *  // open a path to the temp device
 *  path.open();
 *
 *  // read the temp device
 *  byte[] state = tc.readDevice();
 *  tc.doTemperatureConvert(state);
 *  state = tc.readDevice();
 *  System.out.println("Temperature of " +
 *           address + " is " +
 *           tc.getTemperature(state) + " C");
 *
 *  // close the path to the device
 *  path.close();
 * </CODE> </PRE>
 * </DL>
 *
 * @see OWPathElement
 * @see SwitchContainer
 * @see OneWireContainer05
 * @see OneWireContainer12
 * @see OneWireContainer1F
 *
 * @version CLSID=95D46B7C-0D35-470E-BF91-90A1E0E5EF7B -     0.00, 12 September 2000
 * @author     DS
 * @com.register ( clsid=95D46B7C-0D35-470E-BF91-90A1E0E5EF7B, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OWPath
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.utils.OWPath objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public OWPath()
   {
   }

   OWPath(com.dalsemi.onewire.utils.OWPath o)
   {
      this.objectInstance = o;
   }
   OWPath(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.utils.OWPath)o);
   }

   /**
    * Create a new 1-Wire path with no elemements.  Elements
    * can be added by using <CODE> copy </CODE> and/or
    * <CODE> add </CODE>.
    *
    * @param  adapter where the path is based
    *
    * @see #copy(OWPath) copy
    * @see #add(OneWireContainer, int) add
    */
   public void createNewInstance(DSPortAdapter adapter)
   {      
      objectInstance = new com.dalsemi.onewire.utils.OWPath(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance));
   }

   /**
    * Create a new path with a starting path.  New elements
    * can be added with <CODE>add</CODE>.
    *
    * @param  adapter where the 1-Wire path is based
    * @param  currentPath starting value of this 1-Wire path
    *
    * @see #add(OneWireContainer, int) add
    */
   public void createNewInstance(DSPortAdapter adapter, OWPath currentOWPath)
   {      
      objectInstance = new com.dalsemi.onewire.utils.OWPath(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance), ((com.dalsemi.onewire.utils.OWPath)currentOWPath.objectInstance));
   }

   /**
    * Copy the elements from the provided 1-Wire path into this 1-Wire path.
    *
    * @param  currentOWPath path to copy from
    */
   public void copy(OWPath currentOWPath)
   {      
      objectInstance.copy(((com.dalsemi.onewire.utils.OWPath)currentOWPath.objectInstance));
   }

   /**
    * Add a 1-Wire path element to this 1-Wire path.
    *
    * @param owc 1-Wire device switch
    * @param channel of device that represents this 1-Wire path element
    *
    * @see #copy(OWPath) copy
    */
   public void add(OneWireContainer owc, int channel)
   {      
      objectInstance.add(((com.dalsemi.onewire.container.OneWireContainer)owc.objectInstance), channel);
   }

   /**
    * Compare this 1-Wire path with another.
    *
    * @param compareOWPath 1-Wire path to compare to
    *
    * @return <CODE> true </CODE> if the 1-Wire paths are the same
    */
   public boolean equals(OWPath compareOWPath)
   {      
      return objectInstance.equals(((com.dalsemi.onewire.utils.OWPath)compareOWPath.objectInstance));
   }

   /**
    * Get an enumeration of all of the 1-Wire path elements in
    * this 1-Wire path.
    *
    * @return enumeration of all of the 1-Wire path elements
    *
    * @see OWPathElement
    */
   public OWPathEnumeration getAllOWPathElements()
   {      
      return new OWPathEnumeration().setupObject(objectInstance.getAllOWPathElements());
   }

   /**
    * Get a string representation of this 1-Wire path.
    *
    * @return string 1-Wire path as string
    */
   public java.lang.String toString()
   {      
      return objectInstance.toString();
   }

   /**
    * Open this 1-Wire path so that a remote device can be accessed.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         no device present or a CRC read from the device is incorrect.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter.
    */
   public void open()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.open();
   }

   /**
    * Close each element in this 1-Wire path in reverse order.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         no device present or a CRC read from the device is incorrect.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter.
    */
   public void close()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      objectInstance.close();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OWPath setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.utils.OWPath)o;
      return this;
   }
}
