// COM proxy class, output from FunctionList.js
package owapi;
/**
 * The OneWireAccessProvider class manages the Dallas Semiconductor
 * adapter class derivatives of <code>DSPortAdapter</code>.  An enumeration of all
 * available adapters can be accessed through the
 * member function <code>EnumerateAllAdapters</code>.  This enables an
 * application to be adapter independent. There are also facilities to get a system
 * appropriate default adapter/port combination.<p>
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> <H4> Example 1</H4>
 * Get an instance of the default 1-Wire adapter.  The adapter will be ready
 * to use if no exceptions are thrown.
 * <PRE> <CODE>
 *  try
 *  {
 *     DSPortAdapter adapter = OneWireAccessProvider.getDefaultAdapter();
 *
 *     System.out.println("Adapter: " + adapter.getAdapterName() + " Port: " + adapter.getPortName());
 *
 *     // use the adapter ...
 *
 *  }
 *  catch(Exception e)
 *  {
 *     System.out.println("Default adapter not present: " + e);
 *  }
 * </CODE> </PRE>
 * </DL>
 *
 * <DL>
 * <DD> <H4> Example 2</H4>
 * Enumerate through the available adapters and ports.
 * <PRE> <CODE>
 *  DSPortAdapter adapter;
 *  String        port;
 *
 *  // get the adapters
 *  for (Enumeration adapter_enum = OneWireAccessProvider.enumerateAllAdapters();
 *                                  adapter_enum.hasMoreElements(); )
 *  {
 *     // cast the enum as a DSPortAdapter
 *     adapter = ( DSPortAdapter ) adapter_enum.nextElement();
 *
 *     System.out.print("Adapter: " + adapter.getAdapterName() + " with ports: ");
 *
 *     // get the ports
 *     for (Enumeration port_enum = adapter.getPortNames();
 *             port_enum.hasMoreElements(); )
 *     {
 *        // cast the enum as a String
 *        port = ( String ) port_enum.nextElement();
 *
 *        System.out.print(port + " ");
 *     }
 *
 *     System.out.println();
 *  }
 * </CODE> </PRE>
 * </DL>
 *
 * <DL>
 * <DD> <H4> Example 3</H4>
 * Display the default adapter name and port without getting an instance of the adapter.
 * <PRE> <CODE>
 *  System.out.println("Default Adapter: " +
 *                      OneWireAccessProvider.getProperty("onewire.adapter.default"));
 *  System.out.println("Default Port: " +
 *                      OneWireAccessProvider.getProperty("onewire.port.default"));
 * </CODE> </PRE>
 * </DL>
 *
 * @see DSPortAdapter
 *
 * @version CLSID=72431E56-6797-4085-B948-B7CB7FE4BE2E -     0.00, 30 August 2000
 * @author     DS
 * @com.register ( clsid=72431E56-6797-4085-B948-B7CB7FE4BE2E, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireAccessProvider
   implements com.ms.com.IUnknown
{


   /**
    * Returns a version string, representing the release number on official releases,
    * or release number and release date on incrememental releases.
    *
    * @return Current OneWireAPI version
    */
   public java.lang.String getVersion()
   {      
      return com.dalsemi.onewire.OneWireAccessProvider.getVersion();
   }

   /**
    * Gets an <code>Enumeration</code> of all 1-Wire
    * adapter types supported.  Using this enumeration with the port enumeration for
    * each adapter, a search can be done to find all available hardware adapters.
    *
    * @return  <code>Enumeration</code> of <code>DSPortAdapters</code> in the system
    */
   public DSPortAdapterEnumeration enumerateAllAdapters()
   {      
      return new DSPortAdapterEnumeration().setupObject(com.dalsemi.onewire.OneWireAccessProvider.enumerateAllAdapters());
   }

   /**
    * Finds, opens, and verifies the specified adapter on the
    * indicated port.
    *
    * @param adapterName string name of the adapter (match to result
    *             of call to getAdapterName() method in DSPortAdapter)
    * @param portName string name of the port used in the method
    *             selectPort() in DSPortAdapter
    *
    * @return  <code>DSPortAdapter</code> if adapter present
    *
    * @throws OneWireIOException when communcation with the adapter fails
    * @throws OneWireException when the port or adapter not present
    */
   public DSPortAdapter getAdapter(java.lang.String adapterName, java.lang.String portName)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new DSPortAdapter(com.dalsemi.onewire.OneWireAccessProvider.getAdapter(adapterName, portName));
   }

   /**
    * Finds, opens, and verifies the default adapter and
    * port.  Looks for the default adapter/port in the following locations:
    * <p>
    * <ul>
    * <li> Use adapter/port in System.properties for onewire.adapter.default,
    *      and onewire.port.default properties tags.</li>
    * <li> Use adapter/port from onewire.properties file in current directory
    *      or < java.home >/lib/ (Desktop) or /etc/ (TINI)</li>
    * <li> Use smart default
    *      <ul>
    *      <li> Desktop
    *           <ul>
    *           <li> First, TMEX default (Win32 only)
    *           <li> Second, if TMEX not present, then DS9097U/(first serial port)
    *           </ul>
    *      <li> TINI, TINIExternalAdapter on port serial1
    *      </ul>
    * </ul>
    *
    * @return  <code>DSPortAdapter</code> if default adapter present
    *
    * @throws OneWireIOException when communcation with the adapter fails
    * @throws OneWireException when the port or adapter not present
    */
   public DSPortAdapter getDefaultAdapter()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new DSPortAdapter(com.dalsemi.onewire.OneWireAccessProvider.getDefaultAdapter());
   }

   /**
    * Gets the specfied onewire property.
    * Looks for the property in the following locations:
    * <p>
    * <ul>
    * <li> In System.properties
    * <li> In onewire.properties file in current directory
    *      or < java.home >/lib/ (Desktop) or /etc/ (TINI)
    * <li> 'smart' default if property is 'onewire.adapter.default'
    *      or 'onewire.port.default'
    * </ul>
    *
    * @param propName string name of the property to read
    *
    * @return  <code>String</code> representing the property value or <code>null</code> if
    *          it could not be found (<code>onewire.adapter.default</code> and
    *          <code>onewire.port.default</code> may
    *          return a 'smart' default even if property not present)
    */
   public java.lang.String getProperty(java.lang.String propName)
   {      
      return com.dalsemi.onewire.OneWireAccessProvider.getProperty(propName);
   }

   /**
    * Sets an overriding adapter.  This adapter will be returned from
    * getAdapter and getDefaultAdapter despite what was requested.
    *
    * @param adapter adapter to be the override
    *
    * @see    #getAdapter
    * @see    #getDefaultAdapter
    * @see    #clearUseOverridingAdapter
    */
   public void setUseOverridingAdapter(DSPortAdapter adapter)
   {      
      com.dalsemi.onewire.OneWireAccessProvider.setUseOverridingAdapter(((com.dalsemi.onewire.adapter.DSPortAdapter)adapter.objectInstance));
   }

   /**
    * Clears the overriding adapter.  The operation of
    * getAdapter and getDefaultAdapter will be returned to normal.
    *
    * @see    #getAdapter
    * @see    #getDefaultAdapter
    * @see    #setUseOverridingAdapter
    */
   public void clearUseOverridingAdapter()
   {      
      com.dalsemi.onewire.OneWireAccessProvider.clearUseOverridingAdapter();
   }


}
