// COM proxy class, output from FunctionList.js
package owapi;
/**
 * A <code>OneWireContainer</code> encapsulates the <code>DSPortAdapter</code>,
 * the 1-Wire&#174 network address, and methods to manipulate a specific 1-Wire device. A
 * 1-Wire device may be in the form of a stainless steel armored can, called an iButton&#174,
 * or in standard IC plastic packaging.
 *
 * <p>General 1-Wire device container class with basic communication functions.
 * This class should only be used if a device specific class is not available
 * or known.  Most <code>OneWireContainer</code> classes will extend this basic class.
 *
 * <P> 1-Wire devices with memory can be accessed through the objects that
 * are returned from the {@link #getMemoryBanks() getMemoryBanks} method. See the
 * usage example below. </P>
 *
 * <H3> Usage </H3>
 *
 * <DL>
 * <DD> <H4> Example 1</H4>
 * Enumerate memory banks retrieved from the OneWireContainer
 * instance 'owd' and cast to the highest interface.  See the
 * interface descriptions
 * {@link MemoryBank MemoryBank},
 * {@link PagedMemoryBank PagedMemoryBank}, and
 * {@link PagedMemoryBank OTPMemoryBank}
 * for specific examples.
 * <PRE> <CODE>
 *  MemoryBank      mb;
 *  PagedMemoryBank pg_mb;
 *  OTPMemoryBank   otp_mb;
 *
 *  for(Enumeration bank_enum = owd.getMemoryBanks();
 *                      bank_enum.hasMoreElements(); )
 *  {
 *     // get the next memory bank, cast to MemoryBank
 *     mb = (MemoryBank)bank_enum.nextElement();
 *
 *     // check if has paged services
 *     if (mb instanceof PagedMemoryBank)
 *         pg_mb = (PagedMemoryBank)mb;
 *
 *     // check if has One-Time-Programable services
 *     if (mb instanceof OTPMemoryBank)
 *         otp_mb = (OTPMemoryBank)mb;
 *  }
 * </CODE> </PRE>
 * </DL>
 *
 * @see MemoryBank
 * @see PagedMemoryBank
 * @see OTPMemoryBank
 *
 *  @version CLSID=913956BB-CC72-4A9E-A72E-7FC13C9B3FE2 -     0.00, 28 Aug 2000
 *  @author     DS
 * @com.register ( clsid=913956BB-CC72-4A9E-A72E-7FC13C9B3FE2, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer
   implements com.ms.com.IUnknown
{

   com.dalsemi.onewire.container.OneWireContainer objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public OneWireContainer()
   {
      this.objectInstance = new com.dalsemi.onewire.container.OneWireContainer();
   }

   OneWireContainer(com.dalsemi.onewire.container.OneWireContainer o)
   {
      this.objectInstance = o;
   }
   OneWireContainer(java.lang.Object o)
   {
      this.objectInstance = ((com.dalsemi.onewire.container.OneWireContainer)o);
   }

   /**
    * Provides this container with the adapter object used to access this device and
    * the address of the iButton or 1-Wire device.
    *
    * @param  sourceAdapter     adapter object required to communicate with
    *                           this iButton
    * @param  newAddress        address of this 1-Wire device
    * @see Address
    */
   public void setupContainerFromBytes(DSPortAdapter a0, ByteArray a1)
   {      
      objectInstance.setupContainer(((com.dalsemi.onewire.adapter.DSPortAdapter)a0.objectInstance), a1.array);
   }

   /**
    * Provides this container with the adapter object used to access this device and
    * the address of the iButton or 1-Wire device.
    *
    * @param  sourceAdapter     adapter object required to communicate with
    *                           this iButton
    * @param  newAddress        address of this 1-Wire device
    * @see Address
    */
   public void setupContainerFromLong(DSPortAdapter a0, String a1)
   {      
      objectInstance.setupContainer(((com.dalsemi.onewire.adapter.DSPortAdapter)a0.objectInstance), Long.parseLong(a1));
   }

   /**
    * Provides this container with the adapter object used to access this device and
    * the address of the iButton or 1-Wire device.
    *
    * @param  sourceAdapter     adapter object required to communicate with
    *                           this iButton
    * @param  newAddress        address of this 1-Wire device
    * @see Address
    */
   public void setupContainer(DSPortAdapter a0, java.lang.String a1)
   {      
      objectInstance.setupContainer(((com.dalsemi.onewire.adapter.DSPortAdapter)a0.objectInstance), a1);
   }

   /**
    * Retrieves the port adapter object used to create this container.
    *
    * @return port adapter instance
    */
   public DSPortAdapter getAdapter()
   {      
      return new DSPortAdapter(objectInstance.getAdapter());
   }

   /**
    * Retrieves the Dallas Semiconductor part number of the 1-Wire device
    * as a <code>String</code>.  For example 'Crypto iButton' or 'DS1992'.
    *
    * @return 1-Wire device name
    */
   public java.lang.String getName()
   {      
      return objectInstance.getName();
   }

   /**
    * Retrieves the alternate Dallas Semiconductor part numbers or names.
    * A 'family' of 1-Wire Network devices may have more than one part number
    * depending on packaging.  There can also be nicknames such as
    * 'Crypto iButton'.
    *
    * @return 1-Wire device alternate names
    */
   public java.lang.String getAlternateNames()
   {      
      return objectInstance.getAlternateNames();
   }

   /**
    * Retrieves a short description of the function of the 1-Wire device type.
    *
    * @return device functional description
    */
   public java.lang.String getDescription()
   {      
      return objectInstance.getDescription();
   }

   /**
    * Sets the maximum speed for this container.  Note this may be slower then the
    * devices maximum speed.  This method can be used by an application
    * to restrict the communication rate due 1-Wire line conditions. <p>
    *
    * @param newSpeed
    * <ul>
    * <li>     0 (SPEED_REGULAR) set to normal communciation speed
    * <li>     1 (SPEED_FLEX) set to flexible communciation speed used
    *            for long lines
    * <li>     2 (SPEED_OVERDRIVE) set to normal communciation speed to
    *            overdrive
    * <li>     3 (SPEED_HYPERDRIVE) set to normal communciation speed to
    *            hyperdrive
    * <li>    >3 future speeds
    * </ul>
    *
    * @param fallBack boolean indicating it is OK to fall back to a slower
    *                 speed if true
    *
    */
   public void setSpeed(int newSpeed, boolean fallBack)
   {      
      objectInstance.setSpeed(newSpeed, fallBack);
   }

   /**
    * Returns the maximum speed this iButton or 1-Wire device can
    * communicate at.
    * Override this method if derived iButton type can go faster then
    * SPEED_REGULAR(0).
    *
    * @return maximum speed
    * @see DSPortAdapter#setSpeed
    */
   public int getMaxSpeed()
   {      
      return objectInstance.getMaxSpeed();
   }

   /**
    * Gets the 1-Wire Network address of this device as an array of bytes.
    *
    * @return 1-Wire address
    * @see Address
    */
   public ByteArray getAddress()
   {      
      return new ByteArray().setupObject(objectInstance.getAddress());
   }

   /**
    * Gets this device's 1-Wire Network address as a String.
    *
    * @return 1-Wire address
    * @see Address
    */
   public java.lang.String getAddressAsString()
   {      
      return objectInstance.getAddressAsString();
   }

   /**
    * Gets this device's 1-Wire Network address as a long.
    *
    * @return 1-Wire address
    * @see Address
    */
   public String getAddressAsLong()
   {      
      return ""+objectInstance.getAddressAsLong();
   }

   /**
    * Returns an <code>Enumeration</code> of <code>MemoryBank</code>.  Default is no memory banks.
    *
    * @return enumeration of memory banks to read and write memory
    *   on this iButton or 1-Wire device
    * @see MemoryBank
    */
   public MemoryBankEnumeration getMemoryBanks()
   {      
      return new MemoryBankEnumeration().setupObject(objectInstance.getMemoryBanks());
   }

   /**
    * Verifies that the iButton or 1-Wire device is present on
    * the 1-Wire Network.
    *
    * @return  <code>true</code> if device present on the 1-Wire Network
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         a read back verification fails.
    * @throws OneWireException if adapter is not open
    */
   public boolean isPresent()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.isPresent();
   }

   /**
    * Verifies that the iButton or 1-Wire device is present
    * on the 1-Wire Network and in an alarm state.  This does not
    * apply to all device types.
    *
    * @return  <code>true</code> if device present and in alarm condition
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         a read back verification fails.
    * @throws OneWireException if adapter is not open
    */
   public boolean isAlarming()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return objectInstance.isAlarming();
   }

   /**
    * Go to the specified speed for this container.  This method uses the
    * containers selected speed (method setSpeed(speed, fallback)) and
    * will optionally fall back to a slower speed if communciation failed.
    * Only call this method once to get the device into the desired speed
    * as long as the device is still responding.
    *
    * @throws OneWireIOException WHEN selected speed fails and fallback
    *                                 is false
    * @throws OneWireException WHEN hypterdrive is selected speed
    * @see #setSpeed(int,boolean)
    */
   public void doSpeed()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      objectInstance.doSpeed();
   }

   /**
    * Returns a hash code value for the object. This method is
    * supported for the benefit of hashtables such as those provided by
    * <code>java.util.Hashtable</code>.
    *
    * @return  a hash code value for this object.
    * @see     java.util.Hashtable
    */
   public int hashCode()
   {      
      return objectInstance.hashCode();
   }

   /**
    * Indicates whether some other object is "equal to" this one.
    * @param   obj   the reference object with which to compare.
    * @return  <code>true</code> if this object is the same as the obj
    *          argument; <code>false</code> otherwise.
    */
   public boolean equals(java.lang.Object obj)
   {      
      return objectInstance.equals(obj);
   }

   /**
    * Returns a string representation of the object.
    *
    * @return  a string representation of the object.
    */
   public java.lang.String toString()
   {      
      return objectInstance.toString();
   }

   /**
    * Indicates whether or not this class implements the methods defined in the ClockContainer interface.
    * @see owapi.ClockContainer
    */
   public boolean isClockContainer()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.ClockContainer);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the TemperatureContainer interface.
    * @see owapi.TemperatureContainer
    */
   public boolean isTemperatureContainer()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.TemperatureContainer);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the SwitchContainer interface.
    * @see owapi.SwitchContainer
    */
   public boolean isSwitchContainer()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.SwitchContainer);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the HumidityContainer interface.
    * @see owapi.HumidityContainer
    */
   public boolean isHumidityContainer()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.HumidityContainer);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the ADContainer interface.
    * @see owapi.ADContainer
    */
   public boolean isADContainer()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.ADContainer);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the PotentiometerContainer interface.
    * @see owapi.PotentiometerContainer
    */
   public boolean isPotentiometerContainer()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.PotentiometerContainer);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the MissionContainer interface.
    * @see owapi.MissionContainer
    */
   public boolean isMissionContainer()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.MissionContainer);
   }

   /**
    * Indicates whether or not this class implements the methods defined in the PasswordContainer interface.
    * @see owapi.PasswordContainer
    */
   public boolean isPasswordContainer()
   {
      return (this.objectInstance instanceof com.dalsemi.onewire.container.PasswordContainer);
   }

   /**
    * If this class is an instance of OneWireContainer, this method will return the most specific
    * OneWireContainer class.  For example, for a DS1963S, this method will return an instance of
    * OneWireContainer16.
    */
   public OneWireContainer getMostSpecificComponent()
   {
      OneWireContainer owc = this;

         if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer01)
            owc = new OneWireContainer01(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer02)
            owc = new OneWireContainer02(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer04)
            owc = new OneWireContainer04(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer05)
            owc = new OneWireContainer05(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer06)
            owc = new OneWireContainer06(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer08)
            owc = new OneWireContainer08(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer09)
            owc = new OneWireContainer09(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer0A)
            owc = new OneWireContainer0A(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer0B)
            owc = new OneWireContainer0B(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer0C)
            owc = new OneWireContainer0C(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer0F)
            owc = new OneWireContainer0F(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer10)
            owc = new OneWireContainer10(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer12)
            owc = new OneWireContainer12(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer13)
            owc = new OneWireContainer13(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer14)
            owc = new OneWireContainer14(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer16)
            owc = new OneWireContainer16(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer18)
            owc = new OneWireContainer18(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer1A)
            owc = new OneWireContainer1A(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer1D)
            owc = new OneWireContainer1D(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer1F)
            owc = new OneWireContainer1F(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer20)
            owc = new OneWireContainer20(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer21)
            owc = new OneWireContainer21(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer23)
            owc = new OneWireContainer23(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer26)
            owc = new OneWireContainer26(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer28)
            owc = new OneWireContainer28(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer29)
            owc = new OneWireContainer29(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer2C)
            owc = new OneWireContainer2C(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer30)
            owc = new OneWireContainer30(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer33)
            owc = new OneWireContainer33(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer37)
            owc = new OneWireContainer37(objectInstance);
         else if(objectInstance instanceof com.dalsemi.onewire.container.OneWireContainer41)
            owc = new OneWireContainer41(objectInstance);

      return owc;
   }

   /**
    * This method will define this object to hold the same OneWireContainer object as the one
    * passed in.  This is used in early binding, where you create the specific type first, then
    * initialize it with a type returned from another method in the API.
    */
   public void buildFromObject(Object buildOWC)
   {
      throw new RuntimeException("test exception");
      //if(buildOWC instanceof OneWireContainer)
      //   this.objectInstance = ((OneWireContainer)buildOWC).objectInstance;
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer)o;
      return this;
   }
}
