// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire&#174 container for a Dual Addressable Switch, DS2406 or DS2407.
 * This container encapsulates the functionality of the 1-Wire family type <B>12</B> (hex).
 * The DS2406 replaces the DS2407, but does not have hidden mode or user programmable
 * power-on settings.</P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> Open drain PIO pin controlled through 1-Wire communication
 *   <li> 1024-bits of user programmable OTP EPROM
 *   <LI> Operating temperature range from -40&#176C to +85&#176C
 *   <li> On-chip CRC16 generator allows detection of data transfer errors
 *   <li> One or two channels with level sensing abilities
 *   <li> Supports activity sensing
 *   <li> Does not support 'Smart On' capabilities
 *   <li> TO-92 (1 channel) or TSOC (2 channel) packaging
 *   <li> Supports Conditional Search with user-selectable search options
 * </UL>
 *
 * <H3> Memory </H3>
 *
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 *
 * The following is a list of the MemoryBank instances that are returned:
 *
 * <UL>
 *   <LI> <B> Main Memory </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank},
 *                  {@link OTPMemoryBank OTPMemoryBank}
 *         <LI> <I> Size </I> 128 starting at physical address 0
 *         <LI> <I> Features</I> Write-once general-purpose non-volatile needs-program-pulse
 *         <LI> <I> Pages</I> 4 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC pages-redirectable pages-lockable
 *         <li> <i> Extra information for each page</i>  Inverted redirection page, length 1
 *      </UL>
 *   <LI> <B> Write protect pages and Page redirection </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank},
 *                  {@link OTPMemoryBank OTPMemoryBank}
 *         <LI> <I> Size </I> 8 starting at physical address 0 (in STATUS memory area)
 *         <LI> <I> Features</I> Write-once not-general-purpose non-volatile needs-program-pulse
 *         <LI> <I> Pages</I> 1 pages of length 8 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *      </UL>
 * </UL>
 *
 * <H3> Usage </H3>
 *
 * <p>The DS2406 supports level sensing and activity sensing.  The code below
 * reports the flip-flop state, PIO level, and sensed activity while toggling
 * every switch each time through the loop.  It toggles every switch it finds,
 * regardless if the device has one or two switches.</p>
 *
 * <code><pre>
 *      // "ID" is a byte array of size 8 with an address of a part we
 *      // have already found with family code 12 hex
 *      // "access" is a DSPortAdapter
 *
 *      OneWireContainer12 ds2406 = (OneWireContainer12) access.getDeviceContainer(ID);
 *      ds2406.setupContainer(access,ID);
 *
 *      byte[] state = ds2406.readDevice();
 *      int numchannels = ds2406.getNumberChannels(state);
 *      System.out.println("Number of Channels: "+numchannels);
 *      boolean[] switches = new boolean[numchannels];
 *
 *      ds2406.clearActivity();
 *
 *      for (int j=0;j<10;j++)
 *      {
 *          //clear the activity latches halfway through the test
 *          if (j==5)
 *              ds2406.clearActivity();
 *          state = ds2406.readDevice();
 *
 *          //first let's print out the status of all the latches
 *          for (int i=0;i &lt; numchannels;i++)
 *          {
 *              System.out.println("---------------------------------------------------------\r\n");
 *              System.out.println("                       CHANNEL "+i);
 *              System.out.println("---------------------------------------------------------\r\n");
 *
 *              System.out.println("           Latch state: "+ds2406.getLatchState(i,state));
 *              System.out.println("           Level      : "+ds2406.getLevel(i,state));
 *              System.out.println("           Activity   : "+ds2406.getSensedActivity(i, state));
 *              switches[i] = ds2406.getLatchState(i,state);
 *          }
 *
 *          //now lets toggle the switch flip-flop
 *          for (int i=0;i &lt; numchannels;i++)
 *          {
 *              ds2406.setLatchState(i,!switches[i],false,state);
 *          }
 *          ds2406.writeDevice(state);
 *
 *          Thread.sleep(500);
 *      }
 *
 * </pre></code>
 *
 * <p>Also see the usage example in the {@link SwitchContainer SwithContainer}
 * interface.</p>
 *
 * For examples regarding memory operations,
 * <uL>
 * <li> See the usage example in
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <li> See the usage examples in
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </uL>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2406.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2406.pdf for the DS2406</A>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS2407.pdf"> http://pdfserv.maxim-ic.com/arpdf/DS2407.pdf for the DS2407</A>
 * </DL>
 *
 * Also see the {@link 
 *
 * @see OneWireSensor
 * @see SwitchContainer
 * @see OneWireContainer05
 *
 *  @version CLSID=340DD707-D46B-4EB1-AF28-3D1B6337B4AF -     0.00, 28 Aug 2000
 *  @author     KLA,DSS
 * @com.register ( clsid=340DD707-D46B-4EB1-AF28-3D1B6337B4AF, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer12
   extends OneWireContainer
   implements com.ms.com.IUnknown, SwitchContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer12 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer12()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer12());
   }

   OneWireContainer12(com.dalsemi.onewire.container.OneWireContainer12 o)
   {
      super(o);
   }
   OneWireContainer12(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer12)o);
   }

   public static final byte SOURCE_ACTIVITY_LATCH
          = com.dalsemi.onewire.container.OneWireContainer12.SOURCE_ACTIVITY_LATCH;

   public static final byte SOURCE_FLIP_FLOP
          = com.dalsemi.onewire.container.OneWireContainer12.SOURCE_FLIP_FLOP;

   public static final byte SOURCE_PIO
          = com.dalsemi.onewire.container.OneWireContainer12.SOURCE_PIO;

   public static final byte POLARITY_ZERO
          = com.dalsemi.onewire.container.OneWireContainer12.POLARITY_ZERO;

   public static final byte POLARITY_ONE
          = com.dalsemi.onewire.container.OneWireContainer12.POLARITY_ONE;

   public static final byte CHANNEL_NONE
          = com.dalsemi.onewire.container.OneWireContainer12.CHANNEL_NONE;

   public static final byte DONT_CHANGE
          = com.dalsemi.onewire.container.OneWireContainer12.DONT_CHANGE;

   public static final byte CHANNEL_A_ONLY
          = com.dalsemi.onewire.container.OneWireContainer12.CHANNEL_A_ONLY;

   public static final byte CHANNEL_B_ONLY
          = com.dalsemi.onewire.container.OneWireContainer12.CHANNEL_B_ONLY;

   public static final byte CHANNEL_BOTH
          = com.dalsemi.onewire.container.OneWireContainer12.CHANNEL_BOTH;

   public static final byte CRC_DISABLE
          = com.dalsemi.onewire.container.OneWireContainer12.CRC_DISABLE;

   public static final byte CRC_EVERY_BYTE
          = com.dalsemi.onewire.container.OneWireContainer12.CRC_EVERY_BYTE;

   public static final byte CRC_EVERY_8_BYTES
          = com.dalsemi.onewire.container.OneWireContainer12.CRC_EVERY_8_BYTES;

   public static final byte CRC_EVERY_32_BYTES
          = com.dalsemi.onewire.container.OneWireContainer12.CRC_EVERY_32_BYTES;

   /**
    * Checks to see how the DS2406 is being supplied with power.
    * The 6-pin (2 channel) package of the DS2406 can be powered
    * by an outside source, but will still function on
    * parasite power only.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return  <code>true</code> if the device is getting supplied with
    * power and <code>false</code> if the device is parasite powered
    *
    * @see OneWireSensor#readDevice()
    */
   public boolean isPowerSupplied(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).isPowerSupplied(a0.array);
   }

   /**
    * Gets the number of channels supported by this switch.
    * Channel specific methods will use a channel number specified
    * by an integer from [0 to (<code>getNumberChannels(byte[])</code> - 1)].  Note that
    * all devices of the same family will not necessarily have the
    * same number of channels.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the number of channels for this device
    *
    * @see OneWireSensor#readDevice()
    */
   public int getNumberChannels(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).getNumberChannels(a0.array);
   }

   /**
    * Checks if the channels of this switch are 'high side'
    * switches.  This indicates that when 'on' or <code>true</code>, the switch output is
    * connect to the 1-Wire data.  If this method returns  <code>false</code>
    * then when the switch is 'on' or <code>true</code>, the switch is connected
    * to ground.
    *
    * @return <code>true</code> if the switch is a 'high side' switch,
    *         <code>false</code> if the switch is a 'low side' switch
    *
    * @see #getLatchState(int,byte[])
    */
   public boolean isHighSideSwitch()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).isHighSideSwitch();
   }

   /**
    * Checks if the channels of this switch support
    * activity sensing.  If this method returns <code>true</code> then the
    * method <code>getSensedActivity(int,byte[])</code> can be used.
    *
    * @return <code>true</code> if channels support activity sensing
    *
    * @see #getSensedActivity(int,byte[])
    * @see #clearActivity()
    */
   public boolean hasActivitySensing()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).hasActivitySensing();
   }

   /**
    * Checks if the channels of this switch support
    * level sensing.  If this method returns <code>true</code> then the
    * method <code>getLevel(int,byte[])</code> can be used.
    *
    * @return <code>true</code> if channels support level sensing
    *
    * @see #getLevel(int,byte[])
    */
   public boolean hasLevelSensing()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).hasLevelSensing();
   }

   /**
    * Checks if the channels of this switch support
    * 'smart on'. Smart on is the ability to turn on a channel
    * such that only 1-Wire device on this channel are awake
    * and ready to do an operation.  This greatly reduces
    * the time to discover the device down a branch.
    * If this method returns <code>true</code> then the
    * method <code>setLatchState(int,boolean,boolean,byte[])</code>
    * can be used with the <code>doSmart</code> parameter <code>true</code>.
    *
    * @return <code>true</code> if channels support 'smart on'
    *
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean hasSmartOn()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).hasSmartOn();
   }

   /**
    * Checks if the channels of this switch require that only one
    * channel is on at any one time.  If this method returns <code>true</code> then the
    * method <code>setLatchState(int,boolean,boolean,byte[])</code>
    * will not only affect the state of the given
    * channel but may affect the state of the other channels as well
    * to insure that only one channel is on at a time.
    *
    * @return <code>true</code> if only one channel can be on at a time.
    *
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean onlySingleChannelOn()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).onlySingleChannelOn();
   }

   /**
    * Checks the sensed level on the indicated channel.
    * To avoid an exception, verify that this switch
    * has level sensing with the  <code>hasLevelSensing()</code>.
    * Level sensing means that the device can sense the logic
    * level on its PIO pin.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if level sensed is 'high' and <code>false</code> if level sensed is 'low'
    *
    * @see OneWireSensor#readDevice()
    * @see #hasLevelSensing()
    */
   public boolean getLevel(int a0, ByteArray a1)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).getLevel(a0, a1.array);
   }

   /**
    * Checks the latch state of the indicated channel.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if channel latch is 'on'
    * or conducting and <code>false</code> if channel latch is 'off' and not
    * conducting.  Note that the actual output when the latch is 'on'
    * is returned from the <code>isHighSideSwitch()</code> method.
    *
    * @see OneWireSensor#readDevice()
    * @see #isHighSideSwitch()
    * @see #setLatchState(int,boolean,boolean,byte[])
    */
   public boolean getLatchState(int a0, ByteArray a1)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).getLatchState(a0, a1.array);
   }

   /**
    * Checks if the indicated channel has experienced activity.
    * This occurs when the level on the PIO pins changes.  To clear
    * the activity that is reported, call <code>clearActivity()</code>.
    * To avoid an exception, verify that this device supports activity
    * sensing by calling the method <code>hasActivitySensing()</code>.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <code>true</code> if activity was detected and <code>false</code> if no activity was detected
    *
    * @see #hasActivitySensing()
    * @see #clearActivity()
    */
   public boolean getSensedActivity(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).getSensedActivity(channel, state.array);
   }

   /**
    * <p>Clears the activity latches the next time possible.  For
    * example, on a DS2406/07, this happens the next time the
    * status is read with <code>readDevice()</code>.</p>
    *
    * <p>The activity latches will only be cleared once.  With the
    * DS2406/07, this means that only the first call to 
    * <code>readDevice()</code> will clear the activity latches.  
    * Subsequent calls to <code>readDevice()</code> will leave the
    * activity latch states intact, unless this method has been 
    * invoked since the last call to <code>readDevice()</code>.</p>
    *
    * @see OneWireSensor#readDevice()
    * @see #getSensedActivity(int,byte[])
    */
   public void clearActivity()
   {      
      ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).clearActivity();
   }

   /**
    * Sets the latch state of the indicated channel.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.
    *
    * @param channel channel to execute this operation, in the range [0 to (<code>getNumberChannels(byte[])</code> - 1)]
    * @param latchState <code>true</code> to set the channel latch 'on'
    *     (conducting) and <code>false</code> to set the channel latch 'off' (not
    *     conducting).  Note that the actual output when the latch is 'on'
    *     is returned from the <code>isHighSideSwitch()</code> method.
    * @param doSmart If latchState is 'on'/<code>true</code> then doSmart indicates
    *                  if a 'smart on' is to be done.  To avoid an exception
    *                  check the capabilities of this device using the
    *                  <code>hasSmartOn()</code> method.
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #hasSmartOn()
    * @see #getLatchState(int,byte[])
    * @see OneWireSensor#writeDevice(byte[])
    */
   public void setLatchState(int a0, boolean a1, boolean a2, ByteArray a3)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).setLatchState(a0, a1, a2, a3.array);
   }

   /**
    * Retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the 'get'
    * and 'set' methods.  If the device state needs to be changed then call
    * the 'writeDevice' to finalize the changes.
    *
    * @return 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that
    * have been changed by 'set' methods.  Only the state registers that
    * changed are updated.  This is done by referencing a field information
    * appended to the state data.
    *
    * @param  state 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).writeDevice(state.array);
   }

   /**
    * Directs the container to avoid the calls to doSpeed() in methods that communicate
    * with the Thermocron. To ensure that all parts can talk to the 1-Wire bus
    * at their desired speed, each method contains a call
    * to <code>doSpeed()</code>.  However, this is an expensive operation.
    * If a user manages the bus speed in an
    * application,  call this method with <code>doSpeedCheck</code>
    * as <code>false</code>.  The default behavior is
    * to call <code>doSpeed()</code>.
    *
    * @param doSpeedCheck <code>true</code> for <code>doSpeed()</code> to be called before every
    * 1-Wire bus access, <code>false</code> to skip this expensive call
    *
    * @see OneWireContainer#doSpeed()
    */
   public synchronized void setSpeedCheck(boolean doSpeedCheck)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).setSpeedCheck(doSpeedCheck);
   }

    /**
     * <p>Programs the Conditional Search options for the DS2406/2407.</p>
     *
     * <p>The DS2406/2407 supports Conditional Searches with
     * user programmable search conditions.  This means that
     * the part can alarm on several kinds of conditions,
     * programmable by the user.</p>
     *
     * <p>The user can select a channel and a source to compare to
     * a polarity.  If the source's logical value is equal to the
     * polarity, the device alarms (responds to a Conditional Search).
     * For instance, if <code>channel</code> is <code>CHANNEL_A</code>,
     * <code>source</code> is <code>SOURCE_ACTIVITY_LATCH</code>,
     * and <code>polarity</code> is <code>POLARITY_ONE</code>, then the
     * device will respond to a Conditional Search when the activity
     * latch on channel A is 1 (when activity has been detected on
     * channel A).  When <code>channel</code> is <code>CHANNEL_BOTH</code>,
     * the selected source signals are ORed for comparison with the polarity.
     * When <code>channel</code> is <code>CHANNEL_NONE</code>,  the selected
     * source signal is considered a logical '0'.  In other words, if
     * <code>channel</code> is <code>CHANNEL_NONE</code>, if <code>polarity</code>
     * is <code>POLARITY_ZERO</code>, the device always responds to a
     * Conditional Search.  If <code>polarity</code> is <code>POLARITY_ONE</code>,
     * the device never responds to a Conditional Search.</p>
     *
     * <p>Note that for any of these options, the value <code>DONT_CHANGE</code>
     * will insure that the value previously used by the DS2406/2407 will
     * not be altered.</p>
     *
     * <p>The method <code>writeDevice()</code> must be called to finalize
     * changes to the device.  Note that multiple 'set' methods can
     * be called before one call to <code>writeDevice()</code>.</p>
     *
     * <p>Also note that the Hidden Mode of the DS2407 is not supported in this
     * implementation as an option for source selection.  Hidden Mode was
     * phased out for the newer DS2406.  See the datasheet for the DS2407
     * for more information on Hidden Mode.</p>
     *
     * @param channel the channel of interest for the source of the conditional check
     * (valid values are <code>CHANNEL_NONE</code>, <code>CHANNEL_A_ONLY</code>, <code>CHANNEL_B_ONLY</code>, <code>CHANNEL_BOTH</code>, and <code>DONT_CHANGE</code>)
     * @param source the source selection for the conditional check
     * (valid values are <code>SOURCE_ACTIVITY_LATCH</code>, <code>SOURCE_FLIP_FLOP</code>, <code>SOURCE_PIO</code>, and <code>DONT_CHANGE</code>)
     * @param polarity the polarity selection for the conditional check
     * (valid values are <code>POLARITY_ZERO</code>, <code>POLARITY_ONE</code>, and <code>DONT_CHANGE</code>)
     * @param state current state of the device returned from <code>readDevice()</code>
     *
     * @see OneWireSensor#readDevice()
     * @see OneWireSensor#writeDevice(byte[])
     * @see #CHANNEL_NONE
     * @see #CHANNEL_A_ONLY
     * @see #CHANNEL_B_ONLY
     * @see #CHANNEL_BOTH
     * @see #SOURCE_ACTIVITY_LATCH
     * @see #SOURCE_PIO
     * @see #SOURCE_FLIP_FLOP
     * @see #POLARITY_ONE
     * @see #POLARITY_ZERO
     * @see #DONT_CHANGE
     */
   public void setSearchConditions(byte a0, byte a1, byte a2, ByteArray a3)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).setSearchConditions(a0, a1, a2, a3.array);
   }

   /**
    * <p>Accesses the PIO channels to sense the logical status of
    * the output node.  This method supports all the modes of
    * communication with the part as described in the datasheet for
    * the DS2406/2407.</p>
    *
    * @param inbuffer The input buffer.  Depending on the other options chosen
    * to this method, this will contain data to be written to
    * the channels or it will hold space for data that will be read.
    *
    * @param toggleRW By selecting <code>toggleRW</code> to be
    * <code>true</code>, the part will alternately
    * read and write bytes from and to this channel.  Setting
    * <code>toggleRW</code> to <code>false</code> means
    * that only one operation will occur, whichever operation
    * is selected by <code>readInitially</code>. <br> <i> <b> NOTE: </b> 
    * When toggleRW is <code>true</code> the 'read' bytes are
    * automatically provided and only the results of the read
    * bytes are returned. </i>
    *
    * @param readInitially If <code>readInitially</code> is
    * <code>true</code>, the first operation to occur will
    * be a read, else it will be a write.  If <code>toggleRW</code>
    * is <code>false</code>, the operation chosen by this flag
    * is the only operation that will occur.  If <code>toggleRW</code>
    * is <code>true</code>, this operation is the one
    * that will occur first, then the other will occur.  For example,
    * if <code>toggleRW</code> is <code>true</code> and
    * <code>readInitially</code> is <code>false</code> (and you only
    * have one channel communication), 8 bits will be written to channel
    * A and then 8 bits will be read from channel A.
    *
    * @param CRCMode The 2406/7 supports 4 CRC generation modes for error detection
    * when performing channel access.  This argument should have one
    * of the following values:
    * <pre><code>
    *     CRC_DISABLE        Never generate a CRC
    *     CRC_EVERY_BYTE     Generate a CRC after every byte transmission.
    *     CRC_EVERY_8_BYTES  Generate a CRC after every 8 bytes.
    *     CRC_EVERY_32_BYTES Generate a CRC after every 32 bytes.
    * </code></pre>
    * Invalid values will be masked to valid values.  The CRC is 16 bits,
    * and does not get passed back with the output.  This method returns
    * <code>null</code> on a CRC failure.
    *
    * @param channelMode The 2406/7 supports 3 modes of channel communication.  This
    * argument should take one of the following values:
    * <pre><code>
    *     CHANNEL_A_ONLY  Only communicate with PIO A
    *     CHANNEL_B_ONLY  Only communicate with PIO B
    *     CHANNEL_BOTH    Communicate with both PIO's
    * </code></pre>
    * If <code>CHANNEL_BOTH</code> is selected, data is written and read
    * from the input buffer to the two channels.
    * See the datasheet for a description of operation in this
    * mode.  If communicating with both channels, it is up to the
    * caller to format the data correctly in the input buffer
    * so the correct channel gets the correct data.  Similarly,
    * any return data must be parsed by the user.
    *
    * @param clearActivity <code>true</code> to reset the activity latch
    *
    * @param interleave The value for the Interleave Control bit.
    * If <code>true</code>, operates in synchronous mode.
    * If <code>false</code>, operates in asynchronous mode.
    * See the datasheet for a discussion of asynchronous and
    * synchronous mode.  This argument only matters if communicating
    * with both channels.
    *
    * @return If any bytes were read, this returns a byte array of data
    * read from the channel access.  If no bytes were read, it
    * will return the input buffer that was to be written.  
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #CHANNEL_A_ONLY
    * @see #CHANNEL_B_ONLY
    * @see #CHANNEL_BOTH
    * @see #CRC_DISABLE
    * @see #CRC_EVERY_BYTE
    * @see #CRC_EVERY_8_BYTES
    * @see #CRC_EVERY_32_BYTES
    */
   public ByteArray channelAccess(ByteArray inbuffer, boolean toggleRW, boolean readInitially, int CRCMode, int channelMode, boolean clearActivity, boolean interleave)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer12)objectInstance).channelAccess(inbuffer.array, toggleRW, readInitially, CRCMode, channelMode, clearActivity, interleave));
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer12)o;
      return this;
   }
}
