// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire&#174 container for a Thermochron iButton, DS1921.
 * This container encapsulates the functionality of the 1-Wire family type <B>21</B> (hex).
 * </P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> Logs up to 2048 consecutive temperature measurements in nonvolatile, read-only memory
 *   <li> Real-Time clock with programmable alarm
 *   <LI> Programmable high and low temperature alarms
 *   <li> Alarm violation times and durations recorded in nonvolatile, read-only memory
 *   <li> Automatically 'wakes up' and logs temperature at user-programmable intervals
 *   <li> 4096 bits of general-purpose read/write nonvolatile memory
 *   <li> 256-bit scratchpad ensures integrity of data transfer
 *   <li> On-chip 16-bit CRC generator to verify read operations
 *   <li> Long-term histogram with 2&#176 C resolution
 * </UL>
 *
 * <H3> Memory </H3>
 *
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 *
 * The following is a list of the MemoryBank instances that are returned:
 *
 * <UL>
 *   <LI> <B> Scratchpad with CRC </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 page of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <li> <i> Extra information for each page</i>  Target address, offset, length 3
 *      </UL>
 *   <LI> <B> Main Memory </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 512 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 16 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC
 *      </UL>
 *   <LI> <B> Register control </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 512
 *         <LI> <I> Features</I> Read/Write not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 1 pages of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *      </UL>
 *   <LI> <B> Alarm time stamps </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 96 starting at physical address 544
 *         <LI> <I> Features</I> Read-only not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 3 pages of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *      </UL>
 *   <LI> <B> Temperature histogram </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 128 starting at physical address 2048
 *         <LI> <I> Features</I> Read-only not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 4 pages of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *      </UL>
 *   <LI> <B> Temperature log </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 2048 starting at physical address 4096
 *         <LI> <I> Features</I> Read-only not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 64 pages of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *      </UL>
 * </UL>
 *
 * <H3> Usage </H3>
 *
 * <p>The code below starts a mission with the following characteristics:
 * <ul>
 *     <li>Rollover flag enabled.  This means if more than 2048 samples are
 *         taken, the newer samples overwrite the oldest samples in the temperature
 *         log.</li>
 *     <li>High alarm of 28.0&#176 and a low alarm of 23.0&#176 C.  If the alarm is violated,
 *         the Temperature Alarm log will record when and for how long the violation occurred.</li>
 *     <li>The clock alarm enabled to Mondays at 12:30:45 pm.</li>
 *     <li>Sets the Thermocron's Real-Time Clock to the host system's clock.</li>
 *     <li>The mission will start in 2 minutes.</li>
 *     <li>A sample rate of 1 minute.</li>
 * </ul>
 * This code also ensures that the Thermocron's clock is set to run, and that the
 * clock alarm is enabled.</p>
 * <pre><code>
 *       // "ID" is a byte array of size 8 with an address of a part we
 *       // have already found with family code 12 hex
 *       // "access" is a DSPortAdapter
 *       OneWireContainer21 ds1921 = (OneWireContainer21) access.getDeviceContainer(ID);
 *       ds1921.setupContainer(access,ID);
 *       //  ds1921 previously setup as a OneWireContainer21
 *       ds1921.clearMemory();
 *       //  read the current state of the device
 *       byte[] state = ds1921.readDevice();
 *       //  enable rollover
 *       ds1921.setFlag(ds1921.CONTROL_REGISTER, ds1921.ROLLOVER_ENABLE_FLAG, true, state);
 *       //  set the high temperature alarm to 28 C
 *       ds1921.setTemperatureAlarm(ds1921.ALARM_HIGH, 28.0, state);
 *       //  set the low temperature alarm to 23 C
 *       ds1921.setTemperatureAlarm(ds1921.ALARM_LOW, 23.0, state);
 *       //  set the clock alarm to occur weekly, Mondays at 12:30:45 pm
 *       ds1921.setClockAlarm(12, 30, 45, 2, ds1921.ONCE_PER_WEEK, state);
 *       //  set the real time clock to the system's current clock
 *       ds1921.setClock(System.currentTimeMillis(), state);
 *       //  set the mission to start in 2 minutes
 *       ds1921.setMissionStartDelay(2,state);
 *       //  make sure the clock is set to run
 *       ds1921.setClockRunEnable(true, state);
 *       //  make sure the clock alarm is enabled
 *       ds1921.setClockAlarmEnable(true, state);
 *       //  write all that information out
 *       ds1921.writeDevice(state);
 *       //  now enable the mission with a sample rate of 1 minute
 *       ds1921.enableMission(1);
 * </code></pre>
 *
 * <p>The following code processes the temperature log:</p>
 * <code><pre>
 *       byte[] state = ds1921.readDevice();
 *       byte[] log = ds1921.getTemperatureLog(state);
 *       Calendar time_stamp = ds1921.getMissionTimeStamp(state);
 *       long time = time_stamp.getTime().getTime() + ds1921.getFirstLogOffset(state);
 *       int sample_rate = ds1921.getSampleRate(state);
 *
 *       System.out.println("TEMPERATURE LOG");
 *
 *       for (int i=0;i &lt; log.length;i++)
 *       {
 *           System.out.println("- Temperature recorded at  : "+(new Date(time)));
 *           System.out.println("-                     was  : "+ds1921.decodeTemperature(log[i])+" C");
 *           time += sample_rate * 60 * 1000;
 *       }
 * </pre></code>
 *
 * <p>The following code processes the alarm histories:</p>
 * <code><pre>
 *       byte[] high_history = ds1921.getAlarmHistory(ds1921.TEMPERATURE_HIGH_ALARM);
 *       byte[] low_history = ds1921.getAlarmHistory(ds1921.TEMPERATURE_LOW_ALARM);
 *       int sample_rate = ds1921.getSampleRate(state);
 *       int start_offset, violation_count;
 *       System.out.println("ALARM HISTORY");
 *       if (low_history.length==0)
 *       {
 *           System.out.println("- No violations against the low temperature alarm.");
 *           System.out.println("-");
 *       }
 *       for (int i=0;i &lt; low_history.length/4; i++)
 *       {
 *           start_offset = (low_history [i * 4] & 0x0ff)
 *                     | ((low_history [i * 4 + 1] &lt;&lt; 8) & 0x0ff00)
 *                     | ((low_history [i * 4 + 2] &lt;&lt; 16) & 0x0ff0000);
 *           violation_count = 0x0ff & low_history[i*4+3];
 *           System.out.println("- Low alarm started at     : "+(start_offset * sample_rate));
 *           System.out.println("-                          : Lasted "+(violation_count * sample_rate)+" minutes");
 *       }
 *       if (high_history.length==0)
 *       {
 *           System.out.println("- No violations against the high temperature alarm.");
 *           System.out.println("-");
 *       }
 *       for (int i=0;i &lt; high_history.length/4; i++)
 *       {
 *           start_offset = (high_history [i * 4] & 0x0ff)
 *                     | ((high_history [i * 4 + 1] &lt;&lt; 8) & 0x0ff00)
 *                     | ((high_history [i * 4 + 2] &lt;&lt; 16) & 0x0ff0000);
 *           violation_count = 0x0ff & high_history[i*4+3];
 *           System.out.println("- High alarm started at    : "+(start_offset * sample_rate));
 *           System.out.println("-                          : Lasted "+(violation_count * sample_rate)+" minutes");
 *       }
 * </pre></code>
 *
 * <p>The following code processes the temperature histogram:</p>
 * <code><pre>
 *       double resolution = ds1921.getTemperatureResolution();
 *       double histBinWidth = ds1921.getHistogramBinWidth();
 *       double start = ds1921.getHistogramLowTemperature();
 *       System.out.println("TEMPERATURE HISTOGRAM");
 *       for (int i=0;i &lt; histogram.length;i++)
 *       {
 *          System.out.println("- Histogram entry          : "
 *                             + histogram [i] + " at temperature "
 *                             + start + " to "
 *                             + ( start + (histBinWidth - resolution)) + " C");
 *          start += histBinWidth;
 *       }
 * </pre></code>
 *
 * <p>Also see the usage examples in the {@link TemperatureContainer TemperatureContainer}
 * and {@link ClockContainer ClockContainer}
 * interfaces.</p>
 *
 * For examples regarding memory operations,
 * <uL>
 * <li> See the usage example in
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <li> See the usage examples in
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </uL>
 *
 * <H3> DataSheet </H3>
 * <DL>
 * <DD><A HREF="http://pdfserv.maxim-ic.com/arpdf/DS1921L-F5X.pdf">http://pdfserv.maxim-ic.com/arpdf/DS1921L-F5X.pdf</A>
 * </DL>
 *
 * Also visit <a href="http://www.ibutton.com/ibuttons/thermochron.html">
 * http://www.ibutton.com/ibuttons/thermochron.html</a> for links to more
 * sources on the DS1921 Thermocron.
 *
 * @see OneWireSensor
 * @see SwitchContainer
 * @see TemperatureContainer
 *
 * @version CLSID=540CD168-6468-4C40-883E-BABCD0679F8D -     0.00, 28 Aug 2000
 * @author     COlmstea, KLA
 *
 * @com.register ( clsid=540CD168-6468-4C40-883E-BABCD0679F8D, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer21
   extends OneWireContainer
   implements com.ms.com.IUnknown, TemperatureContainer, ClockContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer21 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer21()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer21());
   }

   OneWireContainer21(com.dalsemi.onewire.container.OneWireContainer21 o)
   {
      super(o);
   }
   OneWireContainer21(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer21)o);
   }

   public static final int STATUS_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer21.STATUS_REGISTER;

   public static final int CONTROL_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer21.CONTROL_REGISTER;

   public static final byte ONCE_PER_SECOND
          = com.dalsemi.onewire.container.OneWireContainer21.ONCE_PER_SECOND;

   public static final byte ONCE_PER_MINUTE
          = com.dalsemi.onewire.container.OneWireContainer21.ONCE_PER_MINUTE;

   public static final byte ONCE_PER_HOUR
          = com.dalsemi.onewire.container.OneWireContainer21.ONCE_PER_HOUR;

   public static final byte ONCE_PER_DAY
          = com.dalsemi.onewire.container.OneWireContainer21.ONCE_PER_DAY;

   public static final byte ONCE_PER_WEEK
          = com.dalsemi.onewire.container.OneWireContainer21.ONCE_PER_WEEK;

   public static final byte TEMPERATURE_LOW_ALARM
          = com.dalsemi.onewire.container.OneWireContainer21.TEMPERATURE_LOW_ALARM;

   public static final byte TEMPERATURE_HIGH_ALARM
          = com.dalsemi.onewire.container.OneWireContainer21.TEMPERATURE_HIGH_ALARM;

   public static final byte TIMER_ALARM
          = com.dalsemi.onewire.container.OneWireContainer21.TIMER_ALARM;

   public static final byte TIMER_ALARM_SEARCH_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.TIMER_ALARM_SEARCH_FLAG;

   public static final byte TEMP_HIGH_SEARCH_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.TEMP_HIGH_SEARCH_FLAG;

   public static final byte TEMP_LOW_SEARCH_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.TEMP_LOW_SEARCH_FLAG;

   public static final byte ROLLOVER_ENABLE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.ROLLOVER_ENABLE_FLAG;

   public static final byte MISSION_ENABLE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.MISSION_ENABLE_FLAG;

   public static final byte MEMORY_CLEAR_ENABLE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.MEMORY_CLEAR_ENABLE_FLAG;

   public static final byte OSCILLATOR_ENABLE_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.OSCILLATOR_ENABLE_FLAG;

   public static final byte TIMER_ALARM_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.TIMER_ALARM_FLAG;

   public static final byte TEMPERATURE_HIGH_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.TEMPERATURE_HIGH_FLAG;

   public static final byte TEMPERATURE_LOW_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.TEMPERATURE_LOW_FLAG;

   public static final byte SAMPLE_IN_PROGRESS_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.SAMPLE_IN_PROGRESS_FLAG;

   public static final byte MISSION_IN_PROGRESS_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.MISSION_IN_PROGRESS_FLAG;

   public static final byte MEMORY_CLEARED_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.MEMORY_CLEARED_FLAG;

   public static final byte TEMP_CORE_BUSY_FLAG
          = com.dalsemi.onewire.container.OneWireContainer21.TEMP_CORE_BUSY_FLAG;

   /**
    * Directs the container to avoid the calls to doSpeed() in methods that communicate
    * with the Thermocron. To ensure that all parts can talk to the 1-Wire bus
    * at their desired speed, each method contains a call
    * to <code>doSpeed()</code>.  However, this is an expensive operation.
    * If a user manages the bus speed in an
    * application,  call this method with <code>doSpeedCheck</code>
    * as <code>false</code>.  The default behavior is
    * to call <code>doSpeed()</code>.
    *
    * @param doSpeedCheck <code>true</code> for <code>doSpeed()</code> to be called before every
    * 1-Wire bus access, <code>false</code> to skip this expensive call
    *
    * @see OneWireContainer#doSpeed()
    */
   public synchronized void setSpeedCheck(boolean doSpeedCheck)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setSpeedCheck(doSpeedCheck);
   }

   /**
    * This method returns the low temperature of
    * the thermochron's physical temperature range.
    * The physical range is the range of temperatures
    * that the thermochron can record.
    *
    * The following is a list of physical ranges in
    * degrees Celsius:
    *
    *     DS1921L-F5X = physical range -40 to +85
    *
    *     DS1921H     = physical range 15 to 46
    *
    *     DS1921Z     = physical range -5 to 26
    *
    * @return the physical range low temperature in degrees Celsius
    */
   public double getPhysicalRangeLowTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getPhysicalRangeLowTemperature();
   }

   /**
    * This method returns the high temperature of
    * the thermochron's physical temperature range.
    * The physical range is the range of temperatures
    * that the thermochron can record.
    *
    * The following is a list of physical ranges in
    * degrees Celsius:
    *
    *     DS1921L-F5X = physical range -40 to +85
    *
    *     DS1921H     = physical range 15 to 46
    *
    *     DS1921Z     = physical range -5 to 26
    *
    * @return the physical range low temperature in degrees Celsius
    */
   public double getPhysicalRangeHighTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getPhysicalRangeHighTemperature();
   }

   /**
    * This method returns the low temperature of
    * the thermochron's operating temperature range.
    * The operating range is the range of temperatures
    * for which the thermochron can function properly.
    *
    * The following is a list of operating ranges in
    * degrees Celsius:
    *
    *     DS1921L-F50 = operating range -40 to +85.
    *     DS1921L-F51 = operating range -10 to +85.
    *     DS1921L-F52 = operating range -20 to +85.
    *     DS1921L-F53 = operating range -30 to +85.
    *
    *     DS1921H     = operating range -40 to +85
    *     DS1921Z     = operating range -40 to +85
    *
    * @return the operating range low temperature in degrees Celsius
    */
   public double getOperatingRangeLowTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getOperatingRangeLowTemperature();
   }

   /**
    * This method returns the high temperature of
    * the thermochron's operating temperature range.
    * The operating range is the range of temperatures
    * for which the thermochron can function properly.
    *
    * The following is a list of operating ranges in
    * degrees Celsius:
    *
    *     DS1921L-F50 = operating range -40 to +85.
    *     DS1921L-F51 = operating range -10 to +85.
    *     DS1921L-F52 = operating range -20 to +85.
    *     DS1921L-F53 = operating range -30 to +85.
    *
    *     DS1921H     = operating range -40 to +85
    *     DS1921Z     = operating range -40 to +85
    *
    * @return the operating range high temperature in degrees Celsius
    */
   public double getOperatingRangeHighTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getOperatingRangeHighTemperature();
   }

   /**
    * Retrieves the resolution with which the thermochron takes
    * temperatures in degrees Celsius.
    *
    * @return the temperature resolution of this thermochron.
    */
   public double getTemperatureResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getTemperatureResolution();
   }

   /**
    * Retrieves the lowest temperature of the first histogram bin
    * in degrees Celsius.
    *
    * @return the lowest histogram bin temperature.
    */
   public double getHistogramLowTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getHistogramLowTemperature();
   }

   /**
    * This method returns the width of a histogram bin in degrees
    * Celsius.
    *
    * @return the width of a histogram bin for this thermochron.
    */
   public double getHistogramBinWidth()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getHistogramBinWidth();
   }

   /**
    * Converts a temperature from the DS1921 <code>byte</code> encoded
    * format to degrees Celsius.  The raw temperature readings are unsigned
    * <code>byte</code> values, representing a 2.0 degree accuracy.
    *
    * @param tempByte raw DS1921 temperature reading
    *
    * @return temperature in degrees Celsius
    *
    * @see #encodeTemperature(double)
    */
   public double decodeTemperature(byte tempByte)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).decodeTemperature(tempByte);
   }

   /**
    * Converts a temperature in degrees Celsius to
    * a <code>byte</code> formatted for the DS1921.
    *
    * @param temperature the temperature (Celsius) to convert
    *
    * @return the temperature in raw DS1921 format
    *
    * @see #decodeTemperature(byte)
    */
   public byte encodeTemperature(double temperature)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).encodeTemperature(temperature);
   }

   /**
    * Writes a byte of data into the DS1921's memory. Note that writing to
    * the register page while a mission is in progress ends that mission.
    * Also note that the preferred way to write a page is through the
    * <code>MemoryBank</code> objects returned from the <code>getMemoryBanks()</code>
    * method.
    *
    * @param memAddr the address for writing (in the range of 0x200-0x21F)
    * @param source the data <code>byte</code> to write
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #readByte(int)
    * @see #getMemoryBanks()
    */
   public void writeByte(int memAddr, byte source)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).writeByte(memAddr, source);
   }

   /**
    * Reads a single byte from the DS1921.  Note that the preferred manner
    * of reading from the DS1921 Thermocron is through the <code>readDevice()</code>
    * method or through the <code>MemoryBank</code> objects returned in the
    * <code>getMemoryBanks()</code> method.
    *
    * @param memAddr the address to read from  (in the range of 0x200-0x21F)
    *
    * @return the data byte read
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #writeByte(int,byte)
    * @see #readDevice()
    * @see #getMemoryBanks()
    */
   public byte readByte(int memAddr)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).readByte(memAddr);
   }

   /**
    * <p>Gets the status of the specified flag from the specified register.
    * This method actually communicates with the Thermocron.  To improve
    * performance if you intend to make multiple calls to this method,
    * first call <code>readDevice()</code> and use the
    * <code>getFlag(int, byte, byte[])</code> method instead.</p>
    *
    * <p>The DS1921 Thermocron has two sets of flags.  One set belongs
    * to the control register.  When reading from the control register,
    * valid values for <code>bitMask</code> are:</p>
    * <ul>
    *     <li><code> TIMER_ALARM_SEARCH_FLAG  </code></li>
    *     <li><code> TEMP_HIGH_SEARCH_FLAG    </code></li>
    *     <li><code> TEMP_LOW_SEARCH_FLAG     </code></li>
    *     <li><code> ROLLOVER_ENABLE_FLAG     </code></li>
    *     <li><code> MISSION_ENABLE_FLAG      </code></li>
    *     <li><code> MEMORY_CLEAR_ENABLE_FLAG </code></li>
    *     <li><code> OSCILLATOR_ENABLE_FLAG   </code></li>
    * </ul>
    * <p>When reading from the status register, valid values
    * for <code>bitMask</code> are:</p>
    * <ul>
    *     <li><code> TIMER_ALARM_FLAG         </code></li>
    *     <li><code> TEMPERATURE_HIGH_FLAG    </code></li>
    *     <li><code> TEMPERATURE_LOW_FLAG     </code></li>
    *     <li><code> SAMPLE_IN_PROGRESS_FLAG  </code></li>
    *     <li><code> MISSION_IN_PROGRESS_FLAG </code></li>
    *     <li><code> MEMORY_CLEARED_FLAG      </code></li>
    *     <li><code> TEMP_CORE_BUSY_FLAG      </code></li>
    * </ul>
    *
    * @param register address of register containing the flag (valid values
    * are <code>CONTROL_REGISTER</code> and <code>STATUS_REGISTER</code>)
    * @param bitMask the flag to read (see above for available options)
    *
    * @return the status of the flag, where <code>true</code>
    * signifies a "1" and <code>false</code> signifies a "0"
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #getFlag(int,byte,byte[])
    * @see #readDevice()
    * @see #setFlag(int,byte,boolean)
    * @see #TIMER_ALARM_SEARCH_FLAG
    * @see #TEMP_HIGH_SEARCH_FLAG
    * @see #TEMP_LOW_SEARCH_FLAG
    * @see #ROLLOVER_ENABLE_FLAG
    * @see #MISSION_ENABLE_FLAG
    * @see #MEMORY_CLEAR_ENABLE_FLAG
    * @see #OSCILLATOR_ENABLE_FLAG
    * @see #TIMER_ALARM_FLAG
    * @see #TEMPERATURE_HIGH_FLAG
    * @see #TEMPERATURE_LOW_FLAG
    * @see #SAMPLE_IN_PROGRESS_FLAG
    * @see #MISSION_IN_PROGRESS_FLAG
    * @see #MEMORY_CLEARED_FLAG
    * @see #TEMP_CORE_BUSY_FLAG
    *
    *
    */
   public boolean getFlag(int register, byte bitMask)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getFlag(register, bitMask);
   }

   /**
    * <p>Gets the status of the specified flag from the specified register.
    * This method is the preferred manner of reading the control and
    * status flags.</p>
    *
    * <p>For more information on valid values for the <code>bitMask</code>
    * parameter, see the {@link #getFlag(int,byte) getFlag(int,byte)} method.</p>
    *
    * @param register address of register containing the flag (valid values
    * are <code>CONTROL_REGISTER</code> and <code>STATUS_REGISTER</code>)
    * @param bitMask the flag to read (see {@link #getFlag(int,byte) getFlag(int,byte)}
    * for available options)
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the status of the flag, where <code>true</code>
    * signifies a "1" and <code>false</code> signifies a "0"
    *
    * @see #getFlag(int,byte)
    * @see #readDevice()
    * @see #setFlag(int,byte,boolean,byte[])
    */
   public boolean getFlag(int register, byte bitMask, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getFlag(register, bitMask, state.array);
   }

   /**
    * <p>Sets the status of the specified flag in the specified register.
    * If a mission is in progress a <code>OneWireIOException</code> will be thrown
    * (one cannot write to the registers while a mission is commencing).  This method
    * actually communicates with the DS1921 Thermocron.  To improve
    * performance if you intend to make multiple calls to this method,
    * first call <code>readDevice()</code> and use the
    * <code>setFlag(int,byte,boolean,byte[])</code> method instead.</p>
    *
    * <p>For more information on valid values for the <code>bitMask</code>
    * parameter, see the {@link #getFlag(int,byte) getFlag(int,byte)} method.</p>
    *
    * @param register address of register containing the flag (valid values
    * are <code>CONTROL_REGISTER</code> and <code>STATUS_REGISTER</code>)
    * @param bitMask the flag to read (see {@link #getFlag(int,byte) getFlag(int,byte)}
    * for available options)
    * @param flagValue new value for the flag (<code>true</code> is logic "1")
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         In the case of the DS1921 Thermocron, this could also be due to a
    *         currently running mission.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #getFlag(int,byte)
    * @see #getFlag(int,byte,byte[])
    * @see #setFlag(int,byte,boolean,byte[])
    * @see #readDevice()
    */
   public void setFlag(int register, byte bitMask, boolean flagValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setFlag(register, bitMask, flagValue);
   }

   /**
    * <p>Sets the status of the specified flag in the specified register.
    * If a mission is in progress a <code>OneWireIOException</code> will be thrown
    * (one cannot write to the registers while a mission is commencing).  This method
    * is the preferred manner of setting the DS1921 status and control flags.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.</p>
    *
    * <p>For more information on valid values for the <code>bitMask</code>
    * parameter, see the {@link #getFlag(int,byte) getFlag(int,byte)} method.</p>
    *
    * @param register address of register containing the flag (valid values
    * are <code>CONTROL_REGISTER</code> and <code>STATUS_REGISTER</code>)
    * @param bitMask the flag to read (see {@link #getFlag(int,byte) getFlag(int,byte)}
    * for available options)
    * @param flagValue new value for the flag (<code>true</code> is logic "1")
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #getFlag(int,byte)
    * @see #getFlag(int,byte,byte[])
    * @see #setFlag(int,byte,boolean)
    * @see #readDevice()
    * @see #writeDevice(byte[])
    */
   public void setFlag(int register, byte bitMask, boolean flagValue, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setFlag(register, bitMask, flagValue, state.array);
   }

   /**
    * <p>Begins this DS1921's mission. If a mission is
    * already in progress, this will throw a <code>OneWireIOException</code>.
    * The mission will wait the number of minutes specified by the
    * mission start delay (use <code>setMissionStartDelay()</code>)
    * before beginning.</p>
    *
    * <p>Note that this method actually communicates with the DS1921
    * Thermocron.  No call to <code>writeDevice()</code> is required to
    * finalize mission enabling.  However, some flags (such as the mission
    * start delay) may need to be set with a call to <code>writeDevice()</code>
    * before the mission is enabled.  See the usage section
    * above for an example of starting a mission.</p>
    *
    * @param sampleRate the number of minutes to wait in between temperature samples
    * (valid values are 1 to 255)
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         In the case of the DS1921 Thermocron, this could also be due to a
    *         currently running mission.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #disableMission()
    * @see #setMissionStartDelay(int,byte[])
    * @see #writeDevice(byte[])
    */
   public void enableMission(int sampleRate)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).enableMission(sampleRate);
   }

   /**
    * Ends this DS1921's running mission.  Note that this method
    * actually communicates with the DS1921 Thermocron.  No additional
    * call to <code>writeDevice(byte[])</code> is required.
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #enableMission(int)
    */
   public void disableMission()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).disableMission();
   }

   /**
    * <p>Sets the time to wait before starting the mission.
    * The DS1921 will sleep <code>missionStartDelay</code>
    * minutes after the mission is enabled with <code>enableMission(int)</code>,
    * then begin taking samples.  Only the least significant 16 bits of
    * <code>missionStartDelay</code> are relevant.</p>
    *
    * <p>The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.</p>
    *
    * @param missionStartDelay the time in minutes to delay the first sample
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #readDevice()
    * @see #writeDevice(byte[])
    * @see #enableMission(int)
    */
   public void setMissionStartDelay(int missionStartDelay, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setMissionStartDelay(missionStartDelay, state.array);
   }

   /**
    * <p>Clears the memory of any previous mission.  The memory
    * must be cleared before setting up a new mission. If a
    * mission is in progress a <code>OneWireIOException</code> is thrown.</p>
    *
    * <p>The Clear Memory command clears the Thermocron's memory
    * at address 220h and higher.  It also clears the sample rate, mission
    * start delay, mission time stamp, and mission samples counter.</p>
    *
    * <p>Note that this method actually communicates with the DS1921 Thermocron.
    * No call to <code>writeDevice(byte[])</code> is necessary to finalize this
    * activity.</p>
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         In the case of the DS1921 Thermocron, this could also be due to a
    *         currently running mission.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #enableMission(int)
    * @see #writeDevice(byte[])
    */
   public void clearMemory()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).clearMemory();
   }

   /**
    * <p>Gets the clock alarm time settings.  The alarm settings used by the
    * Thermocron are Hour, Minute, Second, and Day of Week.  Note that not
    * all values in the returned <code>java.util.Calendar</code> object
    * are valid.  Only four values in the <code>Calendar</code> should
    * be used.  The field names for these values are:<pre><code>
    *      Calendar.DAY_OF_MONTH
    *      Calendar.HOUR_OF_DAY
    *      Calendar.MINUTE
    *      Calendar.SECOND</code></pre>
    * </p>
    * <p>To access these fields, use the method <code>Calendar.get(Calendar.HOUR_OF_DAY)</code>.
    * The hour is reported in 24-hour format.  Use the method <code>getClockAlarm(byte[])</code>
    * to find out the next time an alarm event will occur.</p>
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the alarm clock time and day of the week
    *
    * @see #setClockAlarm(int,int,int,int,int,byte[])
    * @see #readDevice()
    * @see #getClockAlarm(byte[])
    */
   public String getAlarmTime(ByteArray state)
   {      
      return "" + ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getAlarmTime(state.array).getTime().getTime();
   }

   /**
    * Set the DS1921's alarm clock.  Some of the parameters
    * might be unimportant depending on the alarm frequency setting.
    * For instance, if the alarm frequency setting is <code>ONCE_PER_MINUTE</code>,
    * then the <code>hour</code> argument is irrelevant.</p>
    *
    * <p>Valid values for <code>alarmFrequency</code> are:<pre><code>
    *    ONCE_PER_SECOND
    *    ONCE_PER_MINUTE
    *    ONCE_PER_HOUR
    *    ONCE_PER_DAY
    *    ONCE_PER_WEEK</code></pre>
    * </p>
    *
    * <p>The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.</p>
    *
    * @param hours the hour of the day (0-23)
    * @param minutes the minute setting (0-59)
    * @param seconds the second setting (0-59)
    * @param day the day of the week (1-7, 1==Sunday)
    * @param alarmFrequency frequency that the alarm should occur at
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #readDevice()
    * @see #writeDevice(byte[])
    * @see #getClockAlarm(byte[])
    * @see #ONCE_PER_SECOND
    * @see #ONCE_PER_MINUTE
    * @see #ONCE_PER_HOUR
    * @see #ONCE_PER_DAY
    * @see #ONCE_PER_WEEK
    */
   public void setClockAlarm(int hours, int minutes, int seconds, int day, int alarmFrequency, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setClockAlarm(hours, minutes, seconds, day, alarmFrequency, state.array);
   }

   /**
    * Returns the rate at which the DS1921 takes temperature samples.
    * This rate is set when the mission is enabled (in the method
    * <code>enableMission(int)</code>.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the time, in minutes, between temperature readings
    *
    * @see #enableMission(int)
    * @see #readDevice()
    */
   public int getSampleRate(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getSampleRate(state.array);
   }

   /**
    * Determines the number of samples taken on this mission.
    * Only the last 2048 samples appear in the Thermocron's log,
    * though all readings from the current mission are logged
    * in the histogram.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the number of samples taken in the current mission
    *
    * @see #readDevice()
    * @see #getDeviceSamplesCounter(byte[])
    */
   public int getMissionSamplesCounter(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getMissionSamplesCounter(state.array);
   }

   /**
    * <p>Determines the total number of samples taken by this Thermocron.
    * This includes samples taken in past missions.  It also includes
    * 'forced' readings.  A 'forced' reading refers to a reading taken
    * when the Thermocron does not have a running mission and is instructed
    * to read the current temperature.</p>
    *
    * <p>The DS1921 Thermocron is tested to last for 1 million temperature
    * readings.</p>
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the total number of measurements taken by this Thermocron
    *
    * @see #readDevice()
    * @see #getMissionSamplesCounter(byte[])
    */
   public int getDeviceSamplesCounter(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getDeviceSamplesCounter(state.array);
   }

   /**
    * Returns the date and time that the last mission was
    * started.  The values in the <code>java.util.Calendar</code>
    * object are fully specified.  In other words, the year, month,
    * date, hour, minute, and second are all valid in the returned
    * object.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the date and time that the last mission was started
    *
    * @see #readDevice()
    */
   public String getMissionTimeStamp(ByteArray state)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getMissionTimeStamp(state.array).getTime().getTime();
   }

   /**
    * <p>Helps determine the times for values in a temperature log.  If rollover
    * is enabled, temperature log entries will over-write previous
    * entries once more than 2048 logs are written.  The returned value can be
    * added to the underlying millisecond value of <code>getMissionTimeStamp()</code>
    * to determine the time that the 'first' log entry actually occurred.</p>
    * <pre><code>
    *      //ds1921 is a OneWireContainer21
    *      byte[] state = ds1921.readDevice();
    *      Calendar c = ds1921.getMissionTimeStamp(state);
    *      //find the time for the first log entry
    *      long first_entry = c.getTime().getTime();
    *      first_entry += ds1921.getFirstLogOffset(state);
    *      . . .
    * </code></pre>
    *
    * <p>Be cautious of Java's Daylight Savings Time offsets when using this
    * function--if you use the <code>Date</code> or <code>Calendar</code>
    * class to print this out, Java may try to automatically format
    * the <code>java.lang.String</code> to handle Daylight Savings Time, resulting in offset
    * by 1 hour problems.</p>
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return milliseconds between the beginning of the mission
    *     and the time of the first log entry reported from
    *     <code>getTemperatureLog()</code>
    *
    * @see #readDevice()
    * @see #getMissionTimeStamp(byte[])
    * @see #getTemperatureLog(byte[])
    */
   public String getFirstLogOffset(ByteArray state)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getFirstLogOffset(state.array);
   }

   /**
    * <p>Returns the log of temperature measurements.  Each <code>byte</code>
    * in the returned array is an independent sample.  Use the method
    * <code>decodeTemperature(byte)</code> to get the double value
    * of the encoded temperature.  See the DS1921 datasheet for more
    * on the data's encoding scheme.  The array's length equals the
    * number of measurements taken thus far.  The temperature log can
    * be read while a mission is still in progress. </p>
    *
    * <p>Note that although this method takes the device state as a parameter,
    * this method still must communicate directly with the Thermocron
    * to read the log.</p>
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the DS1921's encoded temperature log
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #decodeTemperature(byte)
    * @see #readDevice()
    * @see #getFirstLogOffset(byte[])
    * @see #getMissionTimeStamp(byte[])
    */
   public synchronized ByteArray getTemperatureLog(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getTemperatureLog(state.array));
   }

   /**
    * <p>Returns an array of at most 64 counter bins holding the DS1921 histogram data
    * (63 bins for the DS1921L-F5X and 64 bins for the DS1921H or DS1921Z).  For the
    * temperature histogram, the DS1921 provides bins that each consist of a 16-bit,
    * non rolling-over binary counter that is incremented each time a temperature value
    * acquired during a mission falls into the range of the bin. The bin to be
    * updated is determined by cutting off the two least significant bits of the
    * binary temperature value.  For example, on a DS1921L-F5X, bin 0 will hold the
    * counter for temperatures ranging from -40 to -38.5 (Celsius) and lower. Bin 1
    * is associated with the range of -38 to 36.5 and so on.  The last bin, in this
    * case bin 62, holds temperature values of 84 degrees and higher.  Please see the
    * respective DS1921H or DS1921Z datasheets for their bin arrangements.  The
    * temperature histogram can be read while a mission is still in progress.</p>
    *
    * @return the 63 temperature counters
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public IntArray getTemperatureHistogram()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new IntArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getTemperatureHistogram());
   }

   /**
    * Returns <code>true</code> if the specified alarm has been
    * triggered.  Valid values for the <code>alarmBit</code>
    * parameter are:<code><pre>
    *     TEMPERATURE_LOW_ALARM
    *     TEMPERATURE_HIGH_ALARM
    *     TIMER_ALARM
    * </pre></code>
    *
    * @param alarmBit the alarm to check
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return <true> if the specified alarm has been triggered
    *
    * @see #TEMPERATURE_LOW_ALARM
    * @see #TEMPERATURE_HIGH_ALARM
    * @see #TIMER_ALARM
    * @see #readDevice()
    * @see #getAlarmHistory(byte)
    */
   public boolean getAlarmStatus(byte alarmBit, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getAlarmStatus(alarmBit, state.array);
   }

   /**
    * <p>Returns an array containing the alarm log.
    * The DS1921 contains two separate alarm logs. One for the high temperature
    * alarm and one for the low temperature alarm.  Each log can store
    * up to 12 log entries and each log entry will record up to 255
    * consecutive alarm violations.</p>
    *
    * <p>The returned array is not altered from its representation
    * on the DS1921 Thermocron.  It is therefore up to the caller to
    * interpret the data.  The number of logs in this alarm history
    * is equal to the array length divided by 4, since each entry
    * is 4 bytes.  The first three bytes are the number of samples into the
    * mission that the alarm occurred.  The fourth byte is the number of
    * consecutive samples that violated the alarm.  To extract the starting
    * offset and number of violations from the array:</p>
    * <code><pre>
    *       byte[] data = ds1921.getAlarmHistory(OneWireContainer21.TEMPERATURE_HIGH_ALARM);
    *       int start_offset;
    *       int violation_count;
    *       . . .
    *       for (int i=0;i < data.length/4; i++)
    *       {
    *           start_offset = (data [i * 4] & 0x0ff)
    *                     | ((data [i * 4 + 1] << 8) & 0x0ff00)
    *                     | ((data [i * 4 + 2] << 16) & 0x0ff0000);
    *           violation_count = 0x0ff & data[i*4+3];
    *
    *           . . .
    *
    *           // note: you may find it useful to multiply start_offset
    *           //       by getSampleRate() in order to get the number of
    *           //       minutes into the mission that the violation occurred
    *           //       on.  You can do the same with violation_count
    *           //       to determine how long the violation lasted.
    *       }
    * </pre></code>
    *
    * <p>Acceptable values for the <code>alarmBit</code>
    * parameter are:<pre><code>
    *     TEMPERATURE_LOW_ALARM
    *     TEMPERATURE_HIGH_ALARM</code></pre>
    * </p>
    *
    * @param alarmBit the alarm log to get
    *
    * @return the time/duration of the alarm (see above for the structure of the array)
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #getAlarmStatus(byte,byte[])
    */
   public ByteArray getAlarmHistory(byte alarmBit)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getAlarmHistory(alarmBit));
   }

   /**
    * Retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the 'get'
    * and 'set' methods.  If the device state needs to be changed then call
    * the 'writeDevice' to finalize the changes.
    *
    * @return 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that
    * have been changed by 'set' methods.  Only the state registers that
    * changed are updated.  This is done by referencing a field information
    * appended to the state data.
    *
    * @param  state 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).writeDevice(state.array);
   }

   /**
    * Checks to see if this temperature measuring device has high/low
    * trip alarms.
    *
    * @return <code>true</code> if this <code>TemperatureContainer</code>
    *         has high/low trip alarms
    *
    * @see    #getTemperatureAlarm
    * @see    #setTemperatureAlarm
    */
   public boolean hasTemperatureAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).hasTemperatureAlarms();
   }

   /**
    * Checks to see if this device has selectable temperature resolution.
    *
    * @return <code>true</code> if this <code>TemperatureContainer</code>
    *         has selectable temperature resolution
    *
    * @see    #getTemperatureResolution
    * @see    #getTemperatureResolutions
    * @see    #setTemperatureResolution
    */
   public boolean hasSelectableTemperatureResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).hasSelectableTemperatureResolution();
   }

   /**
    * Get an array of available temperature resolutions in Celsius.
    *
    * @return byte array of available temperature resolutions in Celsius with
    *         minimum resolution as the first element and maximum resolution
    *         as the last element
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolution
    * @see    #setTemperatureResolution
    */
   public DoubleArray getTemperatureResolutions()
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getTemperatureResolutions());
   }

   /**
    * Gets the temperature alarm resolution in Celsius.
    *
    * @return temperature alarm resolution in Celsius for this 1-wire device
    *
    * @see    #hasTemperatureAlarms
    * @see    #getTemperatureAlarm
    * @see    #setTemperatureAlarm
    *
    */
   public double getTemperatureAlarmResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getTemperatureAlarmResolution();
   }

   /**
    * Gets the maximum temperature in Celsius.
    *
    * @return maximum temperature in Celsius for this 1-wire device
    *
    * @see #getMinTemperature()
    */
   public double getMaxTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getMaxTemperature();
   }

   /**
    * Gets the minimum temperature in Celsius.
    *
    * @return minimum temperature in Celsius for this 1-wire device
    *
    * @see #getMaxTemperature()
    */
   public double getMinTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getMinTemperature();
   }

   /**
    * Performs a temperature conversion.  Use the <code>state</code>
    * information to calculate the conversion time.
    *
    * @param  state byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         In the case of the DS1921 Thermocron, this could also be due to a
    *         currently running mission.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void doTemperatureConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).doTemperatureConvert(state.array);
   }

   /**
    * Gets the temperature value in Celsius from the <code>state</code>
    * data retrieved from the <code>readDevice()</code> method.
    *
    * @param  state byte array with device state information
    *
    * @return temperature in Celsius from the last
    *                     <code>doTemperatureConvert()</code>
    */
   public double getTemperature(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getTemperature(state.array);
   }

   /**
    * Gets the specified temperature alarm value in Celsius from the
    * <code>state</code> data retrieved from the
    * <code>readDevice()</code> method.
    *
    * @param  alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param  state     byte array with device state information
    *
    * @return temperature alarm trip values in Celsius for this 1-wire device
    *
    * @see    #hasTemperatureAlarms
    * @see    #setTemperatureAlarm
    */
   public double getTemperatureAlarm(int alarmType, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getTemperatureAlarm(alarmType, state.array);
   }

   /**
    * Gets the current temperature resolution in Celsius from the
    * <code>state</code> data retrieved from the <code>readDevice()</code>
    * method.
    *
    * @param  state byte array with device state information
    *
    * @return temperature resolution in Celsius for this 1-wire device
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolutions
    * @see    #setTemperatureResolution
    */
   public double getTemperatureResolution(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getTemperatureResolution(state.array);
   }

   /**
    * Sets the temperature alarm value in Celsius in the provided
    * <code>state</code> data.
    * Use the method <code>writeDevice()</code> with
    * this data to finalize the change to the device.
    *
    * @param  alarmType  valid value: <code>ALARM_HIGH</code> or
    *                    <code>ALARM_LOW</code>
    * @param  alarmValue alarm trip value in Celsius
    * @param  state      byte array with device state information
    *
    * @see    #hasTemperatureAlarms
    * @see    #getTemperatureAlarm
    */
   public void setTemperatureAlarm(int alarmType, double alarmValue, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setTemperatureAlarm(alarmType, alarmValue, state.array);
   }

   /**
    * Sets the current temperature resolution in Celsius in the provided
    * <code>state</code> data.   Use the method <code>writeDevice()</code>
    * with this data to finalize the change to the device.
    *
    * @param  resolution temperature resolution in Celsius
    * @param  state      byte array with device state information
    *
    * @throws OneWireException if the device does not support
    * selectable temperature resolution
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolution
    * @see    #getTemperatureResolutions
    */
   public void setTemperatureResolution(double resolution, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setTemperatureResolution(resolution, state.array);
   }

   /**
    * Checks to see if the clock has an alarm feature.
    *
    * @return true if the Real-Time clock has an alarm
    *
    * @see #getClockAlarm(byte[])
    * @see #isClockAlarmEnabled(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean hasClockAlarm()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).hasClockAlarm();
   }

   /**
    * Checks to see if the clock can be disabled.
    *
    * @return true if the clock can be enabled and disabled
    *
    * @see #isClockRunning(byte[])
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean canDisableClock()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).canDisableClock();
   }

   /**
    * Gets the clock resolution in milliseconds
    *
    * @return the clock resolution in milliseconds
    */
   public String getClockResolution()
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getClockResolution();
   }

   /**
    * Extracts the Real-Time clock value in milliseconds.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the time represented in this clock in milliseconds since 1970
    *
    * @see OneWireSensor#readDevice()
    * @see #setClock(long,byte[])
    */
   public String getClock(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getClock(a0.array);
   }

   /**
    * Extracts the clock alarm value for the Real-Time clock.  In the case
    * of the DS1921 Thermocron, this is the time that the next periodic
    * alarm event will occur.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return milliseconds since 1970 that the clock alarm is set to
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public String getClockAlarm(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).getClockAlarm(a0.array);
   }

   /**
    * Checks if the clock alarm flag has been set.
    * This will occur when the value of the Real-Time
    * clock equals the value of the clock alarm.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if the Real-Time clock is alarming
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean isClockAlarming(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).isClockAlarming(a0.array);
   }

   /**
    * Checks if the clock alarm is enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if clock alarm is enabled
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarming(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean isClockAlarmEnabled(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).isClockAlarmEnabled(a0.array);
   }

   /**
    * Checks if the device's oscillator is enabled.  The clock
    * will not increment if the clock oscillator is not enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if the clock is running
    *
    * @see OneWireSensor#readDevice()
    * @see #canDisableClock()
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean isClockRunning(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).isClockRunning(a0.array);
   }

   /**
    * Sets the Real-Time clock.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.
    *
    * @param time new value for the Real-Time clock, in milliseconds
    * since January 1, 1970
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getClock(byte[])
    */
   public void setClock(String a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setClock(Long.parseLong(a0), a1.array);
   }

   /**
    * Sets the clock alarm.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all clock devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasClockAlarm()</code> method.
    *
    * @param time - new value for the Real-Time clock alarm, in milliseconds
    * since January 1, 1970
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if this device does not have clock alarms
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public void setClockAlarm(String a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setClockAlarm(Long.parseLong(a0), a1.array);
   }

   /**
    * Enables or disables the oscillator, turning the clock 'on' and 'off'.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all clock devices can disable their oscillators.  Check to see if this device can
    * disable its oscillator first by calling the <code>canDisableClock()</code> method.
    *
    * @param runEnable true to enable the clock oscillator
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #canDisableClock()
    * @see #isClockRunning(byte[])
    */
   public void setClockRunEnable(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setClockRunEnable(a0, a1.array);
   }

   /**
    * Enables or disables the clock alarm.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all clock devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasClockAlarm()</code> method.
    *
    * @param alarmEnable true to enable the clock alarm
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #isClockAlarming(byte[])
    */
   public void setClockAlarmEnable(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer21)objectInstance).setClockAlarmEnable(a0, a1.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer21)o;
      return this;
   }
}
