// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P> 1-Wire&#174 container for a Temperature and Humidity/A-D Logging iButton, DS1922.
 * This container encapsulates the functionality of the 1-Wire family type <B>22</B> (hex).
 * </P>
 *
 * <H3> Features </H3>
 * <UL>
 *   <LI> Logs up to 8192 consecutive temperature/humidity/A-D measurements in
 *        nonvolatile, read-only memory
 *   <LI> Real-Time clock
 *   <LI> Programmable high and low temperature alarms
 *   <LI> Programmable high and low humidity/A-D alarms
 *   <LI> Automatically 'wakes up' and logs temperature at user-programmable intervals
 *   <LI> 4096 bits of general-purpose read/write nonvolatile memory
 *   <LI> 256-bit scratchpad ensures integrity of data transfer
 *   <LI> On-chip 16-bit CRC generator to verify read operations
 * </UL>
 *
 * <H3> Memory </H3>
 *
 * <P> The memory can be accessed through the objects that are returned
 * from the {@link #getMemoryBanks() getMemoryBanks} method. </P>
 *
 * The following is a list of the MemoryBank instances that are returned:
 *
 * <UL>
 *   <LI> <B> Scratchpad with CRC and Password support </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 32 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write not-general-purpose volatile
 *         <LI> <I> Pages</I> 1 page of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <li> <i> Extra information for each page</i>  Target address, offset, length 3
 *         <LI> <i> Supports Copy Scratchpad With Password command </I>
 *      </UL>
 *   <LI> <B> Main Memory </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 512 starting at physical address 0
 *         <LI> <I> Features</I> Read/Write general-purpose non-volatile
 *         <LI> <I> Pages</I> 16 pages of length 32 bytes giving 29 bytes Packet data payload
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <LI> <I> Read-Only and Read/Write password </I> if enabled, passwords are required for
 *                  reading from and writing to the device.
 *      </UL>
 *   <LI> <B> Register control </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 64 starting at physical address 512
 *         <LI> <I> Features</I> Read/Write not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 2 pages of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <LI> <I> Read-Only and Read/Write password </I> if enabled, passwords are required for
 *                  reading from and writing to the device.
 *      </UL>
 *   <LI> <B> Temperature/Humidity/A-D log </B>
 *      <UL>
 *         <LI> <I> Implements </I> {@link MemoryBank MemoryBank},
 *                  {@link PagedMemoryBank PagedMemoryBank}
 *         <LI> <I> Size </I> 8192 starting at physical address 4096
 *         <LI> <I> Features</I> Read-only not-general-purpose non-volatile
 *         <LI> <I> Pages</I> 256 pages of length 32 bytes
 *         <LI> <I> Page Features </I> page-device-CRC
 *         <LI> <I> Read-Only and Read/Write password </I> if enabled, passwords are required for
 *                  reading from and writing to the device.
 *      </UL>
 * </UL>
 *
 * <H3> Usage </H3>
 *
 * <p>The code below starts a mission with the following characteristics:
 * <ul>
 *     <li>Rollover flag enabled.</li>
 *     <li>Sets both channels (temperature and humidity) to low resolution</li>
 *     <li>High temperature alarm of 28.0&#176 and a low temperature alarm of 23.0&#176 C.</li>
 *     <li>High humidity alarm of 70%RH and a low temperature alarm of 20%RH.</li>
 *     <li>Sets the Real-Time Clock to the host system's clock.</li>
 *     <li>The mission will start in 2 minutes.</li>
 *     <li>A sample rate of 1.5 minutes.</li>
 * </ul></p>
 * <pre><code>
 *       // "ID" is a byte array of size 8 with an address of a part we
 *       // have already found with family code 22 hex
 *       // "access" is a DSPortAdapter
 *       OneWireContainer41 ds1922 = (OneWireContainer41)access.getDeviceContainer(ID);
 *       ds1922.setupContainer(access,ID);
 *       //  stop the currently running mission, if there is one
 *       ds1922.stopMission();
 *       //  clear the previous mission results
 *       ds1922.clearMemory();
 *       //  set the high temperature alarm to 28 C
 *       ds1922.setMissionAlarm(ds1922.TEMPERATURE_CHANNEL, ds1922.ALARM_HIGH, 28);
 *       ds1922.setMissionAlarmEnable(ds1922.TEMPERATURE_CHANNEL,
 *          ds1922.ALARM_HIGH, true);
 *       //  set the low temperature alarm to 23 C
 *       ds1922.setMissionAlarm(ds1922.TEMPERATURE_CHANNEL, ds1922.ALARM_LOW, 23);
 *       ds1922.setMissionAlarmEnable(ds1922.TEMPERATURE_CHANNEL,
 *          ds1922.ALARM_LOW, true);
 *       //  set the high humidity alarm to 70%RH
 *       ds1922.setMissionAlarm(ds1922.DATA_CHANNEL, ds1922.ALARM_HIGH, 70);
 *       ds1922.setMissionAlarmEnable(ds1922.DATA_CHANNEL,
 *          ds1922.ALARM_HIGH, true);
 *       //  set the low humidity alarm to 20%RH
 *       ds1922.setMissionAlarm(ds1922.DATA_CHANNEL, ds1922.ALARM_LOW, 20);
 *       ds1922.setMissionAlarmEnable(ds1922.DATA_CHANNEL,
 *          ds1922.ALARM_LOW, true);
 *       // set both channels to low resolution.
 *       ds1922.setMissionResolution(ds1922.TEMPERATURE_CHANNEL,
 *          ds1922.getMissionResolutions()[0]);
 *       ds1922.setMissionResolution(ds1922.DATA_CHANNEL,
 *          ds1922.getMissionResolutions()[0]);
 *       // enable both channels
 *       boolean[] enableChannel = new boolean[ds1922.getNumberMissionChannels()];
 *       enableChannel[ds1922.TEMPERATURE_CHANNEL] = true;
 *       enableChannel[ds1922.DATA_CHANNEL] = true;
 *       //  now start the mission with a sample rate of 1 minute
 *       ds1922.startMission(90, 2, true, true, enableChannel);
 * </code></pre>
 * <p>The following code processes the mission log:</p>
 * <code><pre>
 *       System.out.println("Temperature Readings");
 *       if(ds1922.getMissionChannelEnable(owc.TEMPERATURE_CHANNEL))
 *       {
 *          int dataCount =
 *             ds1922.getMissionSampleCount(ds1922.TEMPERATURE_CHANNEL);
 *          System.out.println("SampleCount = " + dataCount);
 *          for(int i=0; i&lt;dataCount; i++)
 *          {
 *             System.out.println(
 *                ds1922.getMissionSample(ds1922.TEMPERATURE_CHANNEL, i));
 *          }
 *       }
 *       System.out.println("Humidity Readings");
 *       if(ds1922.getMissionChannelEnable(owc.DATA_CHANNEL))
 *       {
 *          int dataCount =
 *             ds1922.getMissionSampleCount(ds1922.DATA_CHANNEL);
 *          System.out.println("SampleCount = " + dataCount);
 *          for(int i=0; i&lt;dataCount; i++)
 *          {
 *             System.out.println(
 *                ds1922.getMissionSample(ds1922.DATA_CHANNEL, i));
 *          }
 *       }
 * </pre></code>
 *
 * <p>Also see the usage examples in the {@link TemperatureContainer TemperatureContainer}
 * and {@link ClockContainer ClockContainer}
 * and {@link ADContainer ADContainer}
 * interfaces.</p>
 *
 * For examples regarding memory operations,
 * <uL>
 * <li> See the usage example in
 * {@link OneWireContainer OneWireContainer}
 * to enumerate the MemoryBanks.
 * <li> See the usage examples in
 * {@link MemoryBank MemoryBank} and
 * {@link PagedMemoryBank PagedMemoryBank}
 * for bank specific operations.
 * </uL>
 *
 * <H3> DataSheet </H3>
 * <P>DataSheet link is unavailable at time of publication.  Please visit the website
 * and search for DS1922 or DS2422 to find the current datasheet.
 * <DL>
 * <DD><A HREF="http://www.maxim-ic.com/">Maxim Website</A>
 * </DL>
 *
 * @see OneWireSensor
 * @see SwitchContainer
 * @see TemperatureContainer
 * @see ADContainer
 * @see MissionContainer
 * @see PasswordContainer
 *
 * @version CLSID=12A37CC5-5D4E-450d-8C24-652018EF5C32 -     1.00, 1 June 2003
 * @author     shughes
 *
 * @com.register ( clsid=12A37CC5-5D4E-450d-8C24-652018EF5C32, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class OneWireContainer41
   extends OneWireContainer
   implements com.ms.com.IUnknown, PasswordContainer, MissionContainer, ClockContainer, TemperatureContainer, ADContainer, HumidityContainer 
{

   //Instance defined in super class: OneWireContainer
   //com.dalsemi.onewire.container.OneWireContainer41 objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use setupContainer or buildFromObject methods initialize.
    */
   public OneWireContainer41()
   {
      super(new com.dalsemi.onewire.container.OneWireContainer41());
   }

   OneWireContainer41(com.dalsemi.onewire.container.OneWireContainer41 o)
   {
      super(o);
   }
   OneWireContainer41(java.lang.Object o)
   {
      super((com.dalsemi.onewire.container.OneWireContainer41)o);
   }

   public static final int TEMPERATURE_CHANNEL
          = com.dalsemi.onewire.container.OneWireContainer41.TEMPERATURE_CHANNEL;

   public static final int DATA_CHANNEL
          = com.dalsemi.onewire.container.OneWireContainer41.DATA_CHANNEL;

   public static final byte WRITE_SCRATCHPAD_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer41.WRITE_SCRATCHPAD_COMMAND;

   public static final byte READ_SCRATCHPAD_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer41.READ_SCRATCHPAD_COMMAND;

   public static final byte COPY_SCRATCHPAD_PW_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer41.COPY_SCRATCHPAD_PW_COMMAND;

   public static final byte READ_MEMORY_CRC_PW_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer41.READ_MEMORY_CRC_PW_COMMAND;

   public static final byte CLEAR_MEMORY_PW_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer41.CLEAR_MEMORY_PW_COMMAND;

   public static final byte START_MISSION_PW_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer41.START_MISSION_PW_COMMAND;

   public static final byte STOP_MISSION_PW_COMMAND
          = com.dalsemi.onewire.container.OneWireContainer41.STOP_MISSION_PW_COMMAND;

   public static final byte FORCED_CONVERSION
          = com.dalsemi.onewire.container.OneWireContainer41.FORCED_CONVERSION;

   public static final int RTC_TIME
          = com.dalsemi.onewire.container.OneWireContainer41.RTC_TIME;

   public static final int RTC_DATE
          = com.dalsemi.onewire.container.OneWireContainer41.RTC_DATE;

   public static final int SAMPLE_RATE
          = com.dalsemi.onewire.container.OneWireContainer41.SAMPLE_RATE;

   public static final int TEMPERATURE_LOW_ALARM_THRESHOLD
          = com.dalsemi.onewire.container.OneWireContainer41.TEMPERATURE_LOW_ALARM_THRESHOLD;

   public static final int TEMPERATURE_HIGH_ALARM_THRESHOLD
          = com.dalsemi.onewire.container.OneWireContainer41.TEMPERATURE_HIGH_ALARM_THRESHOLD;

   public static final int DATA_LOW_ALARM_THRESHOLD
          = com.dalsemi.onewire.container.OneWireContainer41.DATA_LOW_ALARM_THRESHOLD;

   public static final int DATA_HIGH_ALARM_THRESHOLD
          = com.dalsemi.onewire.container.OneWireContainer41.DATA_HIGH_ALARM_THRESHOLD;

   public static final int LAST_TEMPERATURE_CONVERSION_LSB
          = com.dalsemi.onewire.container.OneWireContainer41.LAST_TEMPERATURE_CONVERSION_LSB;

   public static final int LAST_TEMPERATURE_CONVERSION_MSB
          = com.dalsemi.onewire.container.OneWireContainer41.LAST_TEMPERATURE_CONVERSION_MSB;

   public static final int LAST_DATA_CONVERSION_LSB
          = com.dalsemi.onewire.container.OneWireContainer41.LAST_DATA_CONVERSION_LSB;

   public static final int LAST_DATA_CONVERSION_MSB
          = com.dalsemi.onewire.container.OneWireContainer41.LAST_DATA_CONVERSION_MSB;

   public static final int TEMPERATURE_CONTROL_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer41.TEMPERATURE_CONTROL_REGISTER;

   public static final byte TCR_BIT_ENABLE_TEMPERATURE_LOW_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.TCR_BIT_ENABLE_TEMPERATURE_LOW_ALARM;

   public static final byte TCR_BIT_ENABLE_TEMPERATURE_HIGH_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.TCR_BIT_ENABLE_TEMPERATURE_HIGH_ALARM;

   public static final int DATA_CONTROL_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer41.DATA_CONTROL_REGISTER;

   public static final byte DCR_BIT_ENABLE_DATA_LOW_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.DCR_BIT_ENABLE_DATA_LOW_ALARM;

   public static final byte DCR_BIT_ENABLE_DATA_HIGH_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.DCR_BIT_ENABLE_DATA_HIGH_ALARM;

   public static final int RTC_CONTROL_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer41.RTC_CONTROL_REGISTER;

   public static final byte RCR_BIT_ENABLE_OSCILLATOR
          = com.dalsemi.onewire.container.OneWireContainer41.RCR_BIT_ENABLE_OSCILLATOR;

   public static final byte RCR_BIT_ENABLE_HIGH_SPEED_SAMPLE
          = com.dalsemi.onewire.container.OneWireContainer41.RCR_BIT_ENABLE_HIGH_SPEED_SAMPLE;

   public static final int MISSION_CONTROL_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer41.MISSION_CONTROL_REGISTER;

   public static final byte MCR_BIT_ENABLE_TEMPERATURE_LOGGING
          = com.dalsemi.onewire.container.OneWireContainer41.MCR_BIT_ENABLE_TEMPERATURE_LOGGING;

   public static final byte MCR_BIT_ENABLE_DATA_LOGGING
          = com.dalsemi.onewire.container.OneWireContainer41.MCR_BIT_ENABLE_DATA_LOGGING;

   public static final byte MCR_BIT_TEMPERATURE_RESOLUTION
          = com.dalsemi.onewire.container.OneWireContainer41.MCR_BIT_TEMPERATURE_RESOLUTION;

   public static final byte MCR_BIT_DATA_RESOLUTION
          = com.dalsemi.onewire.container.OneWireContainer41.MCR_BIT_DATA_RESOLUTION;

   public static final byte MCR_BIT_ENABLE_ROLLOVER
          = com.dalsemi.onewire.container.OneWireContainer41.MCR_BIT_ENABLE_ROLLOVER;

   public static final byte MCR_BIT_START_MISSION_ON_TEMPERATURE_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.MCR_BIT_START_MISSION_ON_TEMPERATURE_ALARM;

   public static final int ALARM_STATUS_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer41.ALARM_STATUS_REGISTER;

   public static final byte ASR_BIT_TEMPERATURE_LOW_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.ASR_BIT_TEMPERATURE_LOW_ALARM;

   public static final byte ASR_BIT_TEMPERATURE_HIGH_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.ASR_BIT_TEMPERATURE_HIGH_ALARM;

   public static final byte ASR_BIT_DATA_LOW_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.ASR_BIT_DATA_LOW_ALARM;

   public static final byte ASR_BIT_DATA_HIGH_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.ASR_BIT_DATA_HIGH_ALARM;

   public static final byte ASR_BIT_BATTERY_ON_RESET
          = com.dalsemi.onewire.container.OneWireContainer41.ASR_BIT_BATTERY_ON_RESET;

   public static final int GENERAL_STATUS_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer41.GENERAL_STATUS_REGISTER;

   public static final byte GSR_BIT_SAMPLE_IN_PROGRESS
          = com.dalsemi.onewire.container.OneWireContainer41.GSR_BIT_SAMPLE_IN_PROGRESS;

   public static final byte GSR_BIT_MISSION_IN_PROGRESS
          = com.dalsemi.onewire.container.OneWireContainer41.GSR_BIT_MISSION_IN_PROGRESS;

   public static final byte GSR_BIT_CONVERSION_IN_PROGRESS
          = com.dalsemi.onewire.container.OneWireContainer41.GSR_BIT_CONVERSION_IN_PROGRESS;

   public static final byte GSR_BIT_MEMORY_CLEARED
          = com.dalsemi.onewire.container.OneWireContainer41.GSR_BIT_MEMORY_CLEARED;

   public static final byte GSR_BIT_WAITING_FOR_TEMPERATURE_ALARM
          = com.dalsemi.onewire.container.OneWireContainer41.GSR_BIT_WAITING_FOR_TEMPERATURE_ALARM;

   public static final byte GSR_BIT_FORCED_CONVERSION_IN_PROGRESS
          = com.dalsemi.onewire.container.OneWireContainer41.GSR_BIT_FORCED_CONVERSION_IN_PROGRESS;

   public static final int MISSION_START_DELAY
          = com.dalsemi.onewire.container.OneWireContainer41.MISSION_START_DELAY;

   public static final int MISSION_TIMESTAMP_TIME
          = com.dalsemi.onewire.container.OneWireContainer41.MISSION_TIMESTAMP_TIME;

   public static final int MISSION_TIMESTAMP_DATE
          = com.dalsemi.onewire.container.OneWireContainer41.MISSION_TIMESTAMP_DATE;

   public static final int DEVICE_CONFIGURATION_BYTE
          = com.dalsemi.onewire.container.OneWireContainer41.DEVICE_CONFIGURATION_BYTE;

   public static final byte DCB_DS2422
          = com.dalsemi.onewire.container.OneWireContainer41.DCB_DS2422;

   public static final byte DCB_DS1923
          = com.dalsemi.onewire.container.OneWireContainer41.DCB_DS1923;

   public static final byte DCB_DS1922L
          = com.dalsemi.onewire.container.OneWireContainer41.DCB_DS1922L;

   public static final byte DCB_DS1922T
          = com.dalsemi.onewire.container.OneWireContainer41.DCB_DS1922T;

   public static final int PASSWORD_CONTROL_REGISTER
          = com.dalsemi.onewire.container.OneWireContainer41.PASSWORD_CONTROL_REGISTER;

   public static final int READ_ACCESS_PASSWORD
          = com.dalsemi.onewire.container.OneWireContainer41.READ_ACCESS_PASSWORD;

   public static final int READ_WRITE_ACCESS_PASSWORD
          = com.dalsemi.onewire.container.OneWireContainer41.READ_WRITE_ACCESS_PASSWORD;

   public static final int MISSION_SAMPLE_COUNT
          = com.dalsemi.onewire.container.OneWireContainer41.MISSION_SAMPLE_COUNT;

   public static final int DEVICE_SAMPLE_COUNT
          = com.dalsemi.onewire.container.OneWireContainer41.DEVICE_SAMPLE_COUNT;

   public static final int MISSION_LOG_SIZE
          = com.dalsemi.onewire.container.OneWireContainer41.MISSION_LOG_SIZE;

   public static final int ODD_MISSION_LOG_SIZE
          = com.dalsemi.onewire.container.OneWireContainer41.ODD_MISSION_LOG_SIZE;

   /**
    * Retrieves the 1-Wire device sensor state.  This state is
    * returned as a byte array.  Pass this byte array to the 'get'
    * and 'set' methods.  If the device state needs to be changed then call
    * the 'writeDevice' to finalize the changes.
    *
    * @return 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public ByteArray readDevice()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new ByteArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).readDevice());
   }

   /**
    * Writes the 1-Wire device sensor state that
    * have been changed by 'set' methods.  Only the state registers that
    * changed are updated.  This is done by referencing a field information
    * appended to the state data.
    *
    * @param  state 1-Wire device sensor state
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void writeDevice(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).writeDevice(state.array);
   }

   /**
    * Reads a single byte from the DS1922.  Note that the preferred manner
    * of reading from the DS1922 Thermocron is through the <code>readDevice()</code>
    * method or through the <code>MemoryBank</code> objects returned in the
    * <code>getMemoryBanks()</code> method.
    *
    * @param memAddr the address to read from  (in the range of 0x200-0x21F)
    *
    * @return the data byte read
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #readDevice()
    * @see #getMemoryBanks()
    */
   public byte readByte(int memAddr)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).readByte(memAddr);
   }

   /**
    * <p>Gets the status of the specified flag from the specified register.
    * This method actually communicates with the DS1922.  To improve
    * performance if you intend to make multiple calls to this method,
    * first call <code>readDevice()</code> and use the
    * <code>getFlag(int, byte, byte[])</code> method instead.</p>
    *
    * <p>The DS1922 has several sets of flags.</p>
    * <ul>
    *    <LI>Register: <CODE> TEMPERATURE_CONTROL_REGISTER </CODE><BR>
    *       Flags:
    *       <UL>
    *          <li><code> TCR_BIT_ENABLE_TEMPERATURE_LOW_ALARM  </code></li>
    *          <li><code> TCR_BIT_ENABLE_TEMPERATURE_HIGH_ALARM </code></li>
    *       </UL>
    *    </LI>
    *    <LI>Register: <CODE> DATA_CONTROL_REGISTER </CODE><BR>
    *       Flags:
    *       <UL>
    *          <li><code> DCR_BIT_ENABLE_DATA_LOW_ALARM  </code></li>
    *          <li><code> DCR_BIT_ENABLE_DATA_HIGH_ALARM </code></li>
    *       </UL>
    *    </LI>
    *    <LI>Register: <CODE> RTC_CONTROL_REGISTER </CODE><BR>
    *       Flags:
    *       <UL>
    *          <li><code> RCR_BIT_ENABLE_OSCILLATOR        </code></li>
    *          <li><code> RCR_BIT_ENABLE_HIGH_SPEED_SAMPLE </code></li>
    *       </UL>
    *    </LI>
    *    <LI>Register: <CODE> MISSION_CONTROL_REGISTER </CODE><BR>
    *       Flags:
    *       <UL>
    *          <li><code> MCR_BIT_ENABLE_TEMPERATURE_LOGGING           </code></li>
    *          <li><code> MCR_BIT_ENABLE_DATA_LOGGING                  </code></li>
    *          <li><code> MCR_BIT_TEMPERATURE_RESOLUTION               </code></li>
    *          <li><code> MCR_BIT_DATA_RESOLUTION                      </code></li>
    *          <li><code> MCR_BIT_ENABLE_ROLLOVER                      </code></li>
    *          <li><code> MCR_BIT_START_MISSION_UPON_TEMPERATURE_ALARM </code></li>
    *       </UL>
    *    </LI>
    *    <LI>Register: <CODE> ALARM_STATUS_REGISTER </CODE><BR>
    *       Flags:
    *       <UL>
    *          <li><code> ASR_BIT_TEMPERATURE_LOW_ALARM  </code></li>
    *          <li><code> ASR_BIT_TEMPERATURE_HIGH_ALARM </code></li>
    *          <li><code> ASR_BIT_DATA_LOW_ALARM         </code></li>
    *          <li><code> ASR_BIT_DATA_HIGH_ALARM        </code></li>
    *          <li><code> ASR_BIT_BATTERY_ON_RESET       </code></li>
    *       </UL>
    *    </LI>
    *    <LI>Register: <CODE> GENERAL_STATUS_REGISTER </CODE><BR>
    *       Flags:
    *       <UL>
    *          <li><code> GSR_BIT_SAMPLE_IN_PROGRESS            </code></li>
    *          <li><code> GSR_BIT_MISSION_IN_PROGRESS           </code></li>
    *          <li><code> GSR_BIT_MEMORY_CLEARED                </code></li>
    *          <li><code> GSR_BIT_WAITING_FOR_TEMPERATURE_ALARM </code></li>
    *       </UL>
    *    </LI>
    * </ul>
    *
    * @param register address of register containing the flag (see above for available options)
    * @param bitMask the flag to read (see above for available options)
    *
    * @return the status of the flag, where <code>true</code>
    * signifies a "1" and <code>false</code> signifies a "0"
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #getFlag(int,byte,byte[])
    * @see #readDevice()
    * @see #setFlag(int,byte,boolean)
    */
   public boolean getFlag(int register, byte bitMask)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getFlag(register, bitMask);
   }

   /**
    * <p>Gets the status of the specified flag from the specified register.
    * This method is the preferred manner of reading the control and
    * status flags.</p>
    *
    * <p>For more information on valid values for the <code>bitMask</code>
    * parameter, see the {@link #getFlag(int,byte) getFlag(int,byte)} method.</p>
    *
    * @param register address of register containing the flag (see
    * {@link #getFlag(int,byte) getFlag(int,byte)} for available options)
    * @param bitMask the flag to read (see {@link #getFlag(int,byte) getFlag(int,byte)}
    * for available options)
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the status of the flag, where <code>true</code>
    * signifies a "1" and <code>false</code> signifies a "0"
    *
    * @see #getFlag(int,byte)
    * @see #readDevice()
    * @see #setFlag(int,byte,boolean,byte[])
    */
   public boolean getFlag(int register, byte bitMask, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getFlag(register, bitMask, state.array);
   }

   /**
    * <p>Sets the status of the specified flag in the specified register.
    * If a mission is in progress a <code>OneWireIOException</code> will be thrown
    * (one cannot write to the registers while a mission is commencing).  This method
    * actually communicates with the DS1922.  To improve
    * performance if you intend to make multiple calls to this method,
    * first call <code>readDevice()</code> and use the
    * <code>setFlag(int,byte,boolean,byte[])</code> method instead.</p>
    *
    * <p>For more information on valid values for the <code>bitMask</code>
    * parameter, see the {@link #getFlag(int,byte) getFlag(int,byte)} method.</p>
    *
    * @param register address of register containing the flag (see
    * {@link #getFlag(int,byte) getFlag(int,byte)} for available options)
    * @param bitMask the flag to read (see {@link #getFlag(int,byte) getFlag(int,byte)}
    * for available options)
    * @param flagValue new value for the flag (<code>true</code> is logic "1")
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         In the case of the DS1922, this could also be due to a
    *         currently running mission.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    *
    * @see #getFlag(int,byte)
    * @see #getFlag(int,byte,byte[])
    * @see #setFlag(int,byte,boolean,byte[])
    * @see #readDevice()
    */
   public void setFlag(int register, byte bitMask, boolean flagValue)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setFlag(register, bitMask, flagValue);
   }

   /**
    * <p>Sets the status of the specified flag in the specified register.
    * If a mission is in progress a <code>OneWireIOException</code> will be thrown
    * (one cannot write to the registers while a mission is commencing).  This method
    * is the preferred manner of setting the DS1922 status and control flags.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.</p>
    *
    * <p>For more information on valid values for the <code>bitMask</code>
    * parameter, see the {@link #getFlag(int,byte) getFlag(int,byte)} method.</p>
    *
    * @param register address of register containing the flag (see
    * {@link #getFlag(int,byte) getFlag(int,byte)} for available options)
    * @param bitMask the flag to read (see {@link #getFlag(int,byte) getFlag(int,byte)}
    * for available options)
    * @param flagValue new value for the flag (<code>true</code> is logic "1")
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #getFlag(int,byte)
    * @see #getFlag(int,byte,byte[])
    * @see #setFlag(int,byte,boolean)
    * @see #readDevice()
    * @see #writeDevice(byte[])
    */
   public void setFlag(int register, byte bitMask, boolean flagValue, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setFlag(register, bitMask, flagValue, state.array);
   }

   /**
    * Returns instance of the memory bank representing this device's
    * scratchpad.
    *
    * @return scratchpad memory bank
    */
   public MemoryBankScratchCRCPW getScratchpadMemoryBank()
   {      
      return new MemoryBankScratchCRCPW(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getScratchpadMemoryBank());
   }

   /**
    * Returns instance of the memory bank representing this device's
    * general-purpose user data memory.
    *
    * @return user data memory bank
    */
   public MemoryBankNVCRCPW getUserDataMemoryBank()
   {      
      return new MemoryBankNVCRCPW(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getUserDataMemoryBank());
   }

   /**
    * Returns instance of the memory bank representing this device's
    * data log.
    *
    * @return data log memory bank
    */
   public MemoryBankNVCRCPW getDataLogMemoryBank()
   {      
      return new MemoryBankNVCRCPW(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getDataLogMemoryBank());
   }

   /**
    * Returns instance of the memory bank representing this device's
    * special function registers.
    *
    * @return register memory bank
    */
   public MemoryBankNVCRCPW getRegisterMemoryBank()
   {      
      return new MemoryBankNVCRCPW(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getRegisterMemoryBank());
   }

   /**
    * Returns the Device Configuration Byte, which specifies whether or
    * not this device is a DS1922, DS1923, or DS2422.
    * 
    * @return the Device Configuration Byte
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public byte getDeviceConfigByte()
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getDeviceConfigByte();
   }

   /**
    * Directs the container to avoid the calls to doSpeed() in methods that communicate
    * with the DS1922/DS2422. To ensure that all parts can talk to the 1-Wire bus
    * at their desired speed, each method contains a call
    * to <code>doSpeed()</code>.  However, this is an expensive operation.
    * If a user manages the bus speed in an
    * application,  call this method with <code>doSpeedCheck</code>
    * as <code>false</code>.  The default behavior is
    * to call <code>doSpeed()</code>.
    *
    * @param doSpeedCheck <code>true</code> for <code>doSpeed()</code> to be called before every
    * 1-Wire bus access, <code>false</code> to skip this expensive call
    *
    * @see OneWireContainer#doSpeed()
    */
   public synchronized void setSpeedCheck(boolean doSpeedCheck)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setSpeedCheck(doSpeedCheck);
   }

   /**
    * Stops the currently running mission.
    *
    */
   public void stopMission()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).stopMission();
   }

   /**
    * Starts a new mission.  Assumes all parameters have been set by either
    * writing directly to the device registers, or by calling other setup
    * methods.
    */
   public void startMission()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).startMission();
   }

   /**
    * Erases the log memory from this missioning device.
    */
   public void clearMemory()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).clearMemory();
   }

   /**
    * Returns the length in bytes of the Read-Only password.
    *
    * @return the length in bytes of the Read-Only password.
    */
   public int getReadOnlyPasswordLength()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getReadOnlyPasswordLength();
   }

   /**
    * Returns the length in bytes of the Read/Write password.
    *
    * @return the length in bytes of the Read/Write password.
    */
   public int getReadWritePasswordLength()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getReadWritePasswordLength();
   }

   /**
    * Returns the length in bytes of the Write-Only password.
    *
    * @return the length in bytes of the Write-Only password.
    */
   public int getWriteOnlyPasswordLength()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getWriteOnlyPasswordLength();
   }

   /**
    * Returns the absolute address of the memory location where
    * the Read-Only password is written.
    *
    * @return the absolute address of the memory location where
    *         the Read-Only password is written.
    */
   public int getReadOnlyPasswordAddress()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getReadOnlyPasswordAddress();
   }

   /**
    * Returns the absolute address of the memory location where
    * the Read/Write password is written.
    *
    * @return the absolute address of the memory location where
    *         the Read/Write password is written.
    */
   public int getReadWritePasswordAddress()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getReadWritePasswordAddress();
   }

   /**
    * Returns the absolute address of the memory location where
    * the Write-Only password is written.
    *
    * @return the absolute address of the memory location where
    *         the Write-Only password is written.
    */
   public int getWriteOnlyPasswordAddress()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getWriteOnlyPasswordAddress();
   }

   /**
    * Returns true if this device has a Read-Only password.
    * If false, all other functions dealing with the Read-Only
    * password will throw an exception if called.
    *
    * @return <code>true</code> always, since DS1922 has Read-Only password.
    */
   public boolean hasReadOnlyPassword()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasReadOnlyPassword();
   }

   /**
    * Returns true if this device has a Read/Write password.
    * If false, all other functions dealing with the Read/Write
    * password will throw an exception if called.
    *
    * @return <code>true</code> always, since DS1922 has Read/Write password.
    */
   public boolean hasReadWritePassword()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasReadWritePassword();
   }

   /**
    * Returns true if this device has a Write-Only password.
    * If false, all other functions dealing with the Write-Only
    * password will throw an exception if called.
    *
    * @return <code>false</code> always, since DS1922 has no Write-Only password.
    */
   public boolean hasWriteOnlyPassword()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasWriteOnlyPassword();
   }

   /**
    * Returns true if the device's Read-Only password has been enabled.
    *
    * @return <code>true</code> if the device's Read-Only password has been enabled.
    */
   public boolean getDeviceReadOnlyPasswordEnable()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getDeviceReadOnlyPasswordEnable();
   }

   /**
    * Returns true if the device's Read/Write password has been enabled.
    *
    * @return <code>true</code> if the device's Read/Write password has been enabled.
    */
   public boolean getDeviceReadWritePasswordEnable()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getDeviceReadWritePasswordEnable();
   }

   /**
    * Returns true if the device's Write-Only password has been enabled.
    *
    * @return <code>true</code> if the device's Write-Only password has been enabled.
    */
   public boolean getDeviceWriteOnlyPasswordEnable()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getDeviceWriteOnlyPasswordEnable();
   }

   /**
    * Returns true if this device has the capability to enable one type of password
    * while leaving another type disabled.  i.e. if the device has Read-Only password
    * protection and Write-Only password protection, this method indicates whether or
    * not you can enable Read-Only protection while leaving the Write-Only protection
    * disabled.
    *
    * @return <code>true</code> if the device has the capability to enable one type
    *         of password while leaving another type disabled.
    */
   public boolean hasSinglePasswordEnable()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasSinglePasswordEnable();
   }

   /**
    * <p>Enables/Disables passwords for this Device.  This method allows you to
    * individually enable the different types of passwords for a particular
    * device.  If <code>hasSinglePasswordEnable()</code> returns true,
    * you can selectively enable particular types of passwords.  Otherwise,
    * this method will throw an exception if all supported types are not
    * enabled.</p>
    *
    * <p>For this to be successful, either write-protect passwords must be disabled,
    * or the write-protect password(s) for this container must be set and must match
    * the value of the write-protect password(s) in the device's register.</p>
    *
    * <P><B>
    * WARNING: Enabling passwords requires that both the read password and the
    * read/write password be re-written to the part.  Before calling this method,
    * you should set the container read password and read/write password values.
    * This will ensure that the correct value is written into the part.
    * </B></P>
    *
    * @param enableReadOnly if <code>true</code> Read-Only passwords will be enabled.
    * @param enableReadWrite if <code>true</code> Read/Write passwords will be enabled.
    * @param enableWriteOnly if <code>true</code> Write-Only passwords will be enabled.
    */
   public void setDevicePasswordEnable(boolean enableReadOnly, boolean enableReadWrite, boolean enableWriteOnly)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setDevicePasswordEnable(enableReadOnly, enableReadWrite, enableWriteOnly);
   }

   /**
    * <p>Enables/Disables passwords for this device.  If the part has more than one
    * type of password (Read-Only, Write-Only, or Read/Write), all passwords
    * will be enabled.  This function is equivalent to the following:
    *    <code> owc41.setDevicePasswordEnable(
    *                    owc41.hasReadOnlyPassword(),
    *                    owc41.hasReadWritePassword(),
    *                    owc41.hasWriteOnlyPassword() ); </code></p>
    *
    * <p>For this to be successful, either write-protect passwords must be disabled,
    * or the write-protect password(s) for this container must be set and must match
    * the value of the write-protect password(s) in the device's register.</P>
    *
    * <P><B>
    * WARNING: Enabling passwords requires that both the read password and the
    * read/write password be re-written to the part.  Before calling this method,
    * you should set the container read password and read/write password values.
    * This will ensure that the correct value is written into the part.
    * </B></P>
    *
    * @param enableAll if <code>true</code>, all passwords are enabled.  Otherwise,
    *        all passwords are disabled.
    */
   public void setDevicePasswordEnableAll(boolean enableAll)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setDevicePasswordEnableAll(enableAll);
   }

   /**
    * <p>Writes the given password to the device's Read-Only password register.  Note
    * that this function does not enable the password, just writes the value to
    * the appropriate memory location.</p>
    *
    * <p>For this to be successful, either write-protect passwords must be disabled,
    * or the write-protect password(s) for this container must be set and must match
    * the value of the write-protect password(s) in the device's register.</p>
    *
    * <P><B>
    * WARNING: Setting the read password requires that both the read password
    * and the read/write password be written to the part.  Before calling this
    * method, you should set the container read/write password value.
    * This will ensure that the correct value is written into the part.
    * </B></P>
    *
    * @param password the new password to be written to the device's Read-Only
    *        password register.  Length must be
    *        <code>(offset + getReadOnlyPasswordLength)</code>
    * @param offset the starting point for copying from the given password array
    */
   public void setDeviceReadOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setDeviceReadOnlyPassword(password.array, offset);
   }

   /**
    * <p>Writes the given password to the device's Read/Write password register.  Note
    * that this function does not enable the password, just writes the value to
    * the appropriate memory location.</p>
    *
    * <p>For this to be successful, either write-protect passwords must be disabled,
    * or the write-protect password(s) for this container must be set and must match
    * the value of the write-protect password(s) in the device's register.</p>
    *
    * @param password the new password to be written to the device's Read-Write
    *        password register.  Length must be
    *        <code>(offset + getReadWritePasswordLength)</code>
    * @param offset the starting point for copying from the given password array
    */
   public void setDeviceReadWritePassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setDeviceReadWritePassword(password.array, offset);
   }

   /**
    * <p>Writes the given password to the device's Write-Only password register.  Note
    * that this function does not enable the password, just writes the value to
    * the appropriate memory location.</p>
    *
    * <p>For this to be successful, either write-protect passwords must be disabled,
    * or the write-protect password(s) for this container must be set and must match
    * the value of the write-protect password(s) in the device's register.</p>
    *
    * @param password the new password to be written to the device's Write-Only
    *        password register.  Length must be
    *        <code>(offset + getWriteOnlyPasswordLength)</code>
    * @param offset the starting point for copying from the given password array
    */
   public void setDeviceWriteOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setDeviceWriteOnlyPassword(password.array, offset);
   }

   /**
    * Sets the Read-Only password used by the API when reading from the
    * device's memory.  This password is not written to the device's
    * Read-Only password register.  It is the password used by the
    * software for interacting with the device only.
    *
    * @param password the new password to be used by the API when
    *        reading from the device's memory.  Length must be
    *        <code>(offset + getReadOnlyPasswordLength)</code>
    * @param offset the starting point for copying from the given password array
    */
   public void setContainerReadOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setContainerReadOnlyPassword(password.array, offset);
   }

   /**
    * Sets the Read/Write password used by the API when reading from  or
    * writing to the device's memory.  This password is not written to
    * the device's Read/Write password register.  It is the password used
    * by the software for interacting with the device only.
    *
    * @param password the new password to be used by the API when
    *        reading from or writing to the device's memory.  Length must be
    *        <code>(offset + getReadWritePasswordLength)</code>
    * @param offset the starting point for copying from the given password array
    */
   public void setContainerReadWritePassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setContainerReadWritePassword(password.array, offset);
   }

   /**
    * Sets the Write-Only password used by the API when writing to the
    * device's memory.  This password is not written to the device's
    * Write-Only password register.  It is the password used by the
    * software for interacting with the device only.
    *
    * @param password the new password to be used by the API when
    *        writing to the device's memory.  Length must be
    *        <code>(offset + getWriteOnlyPasswordLength)</code>
    * @param offset the starting point for copying from the given password array
    */
   public void setContainerWriteOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setContainerWriteOnlyPassword(password.array, offset);
   }

   /**
    * Returns true if the password used by the API for reading from the
    * device's memory has been set.  The return value is not affected by
    * whether or not the read password of the container actually matches
    * the value in the device's password register
    *
    * @return <code>true</code> if the password used by the API for
    * reading from the device's memory has been set.
    */
   public boolean isContainerReadOnlyPasswordSet()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isContainerReadOnlyPasswordSet();
   }

   /**
    * Returns true if the password used by the API for reading from or
    * writing to the device's memory has been set.  The return value is
    * not affected by whether or not the read/write password of the
    * container actually matches the value in the device's password
    * register.
    *
    * @return <code>true</code> if the password used by the API for
    * reading from or writing to the device's memory has been set.
    */
   public boolean isContainerReadWritePasswordSet()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isContainerReadWritePasswordSet();
   }

   /**
    * Returns true if the password used by the API for writing to the
    * device's memory has been set.  The return value is not affected by
    * whether or not the write password of the container actually matches
    * the value in the device's password register.
    *
    * @return <code>true</code> if the password used by the API for
    * writing to the device's memory has been set.
    */
   public boolean isContainerWriteOnlyPasswordSet()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isContainerWriteOnlyPasswordSet();
   }

   /**
    * Gets the Read-Only password used by the API when reading from the
    * device's memory.  This password is not read from the device's
    * Read-Only password register.  It is the password used by the
    * software for interacting with the device only and must have been
    * set using the <code>setContainerReadOnlyPassword</code> method.
    *
    * @param password array for holding the password that is used by the
    *        API when reading from the device's memory.  Length must be
    *        <code>(offset + getWriteOnlyPasswordLength)</code>
    * @param offset the starting point for copying into the given password array
    */
   public void getContainerReadOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getContainerReadOnlyPassword(password.array, offset);
   }

   /**
    * Gets the Read/Write password used by the API when reading from or
    * writing to the device's memory.  This password is not read from
    * the device's Read/Write password register.  It is the password used
    * by the software for interacting with the device only and must have
    * been set using the <code>setContainerReadWritePassword</code> method.
    *
    * @param password array for holding the password that is used by the
    *        API when reading from or writing to the device's memory.  Length must be
    *        <code>(offset + getReadWritePasswordLength)</code>
    * @param offset the starting point for copying into the given password array
    */
   public void getContainerReadWritePassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getContainerReadWritePassword(password.array, offset);
   }

   /**
    * Gets the Write-Only password used by the API when writing to the
    * device's memory.  This password is not read from the device's
    * Write-Only password register.  It is the password used by the
    * software for interacting with the device only and must have been
    * set using the <code>setContainerWriteOnlyPassword</code> method.
    *
    * @param password array for holding the password that is used by the
    *        API when writing to the device's memory.  Length must be
    *        <code>(offset + getWriteOnlyPasswordLength)</code>
    * @param offset the starting point for copying into the given password array
    */
   public void getContainerWriteOnlyPassword(ByteArray password, int offset)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getContainerWriteOnlyPassword(password.array, offset);
   }

   /**
    * Returns a default friendly label for each channel supported by this
    * Missioning device.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return friendly label for the specified channel
    */
   public java.lang.String getMissionLabel(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionLabel(channel);
   }

   /**
    * Sets the SUTA (Start Upon Temperature Alarm) bit in the Mission Control
    * register.  This method will communicate with the device directly.
    *
    * @param enable sets/clears the SUTA bit in the Mission Control register.
    */
   public void setStartUponTemperatureAlarmEnable(boolean enable)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setStartUponTemperatureAlarmEnable(enable);
   }

   /**
    * Sets the SUTA (Start Upon Temperature Alarm) bit in the Mission Control
    * register.  This method will set the bit in the provided 'state' array,
    * which should be acquired through a call to <code>readDevice()</code>.
    * After updating the 'state', the method <code>writeDevice(byte[])</code>
    * should be called to commit your changes.
    *
    * @param enable sets/clears the SUTA bit in the Mission Control register.
    * @param state current state of the device returned from <code>readDevice()</code>
    */
   public void setStartUponTemperatureAlarmEnable(boolean enable, ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setStartUponTemperatureAlarmEnable(enable, state.array);
   }

   /**
    * Returns true if the SUTA (Start Upon Temperature Alarm) bit in the
    * Mission Control register is set.  This method will communicate with
    * the device to read the status of the SUTA bit.
    *
    * @return <code>true</code> if the SUTA bit in the Mission Control register is set.
    */
   public boolean isStartUponTemperatureAlarmEnabled()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isStartUponTemperatureAlarmEnabled();
   }

   /**
    * Returns true if the SUTA (Start Upon Temperature Alarm) bit in the
    * Mission Control register is set.  This method will check for  the bit
    * in the provided 'state' array, which should be acquired through a call
    * to <code>readDevice()</code>.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    * @return <code>true</code> if the SUTA bit in the Mission Control register is set.
    */
   public boolean isStartUponTemperatureAlarmEnabled(ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isStartUponTemperatureAlarmEnabled(state.array);
   }

   /**
    * Returns true if the currently loaded mission results indicate
    * that this mission has the SUTA bit enabled.
    *
    * @return <code>true</code> if the currently loaded mission
    *         results indicate that this mission has the SUTA bit
    *         enabled.
    */
   public boolean isMissionSUTA()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isMissionSUTA();
   }

   /**
    * Returns true if the currently loaded mission results indicate
    * that this mission has the SUTA bit enabled and is still
    * Waiting For Temperature Alarm (WFTA).
    *
    * @return <code>true</code> if the currently loaded mission
    *         results indicate that this mission has the SUTA bit
    *         enabled and is still Waiting For Temperature Alarm (WFTA).
    */
   public boolean isMissionWFTA()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isMissionWFTA();
   }

   /**
    * Begins a new mission on this missioning device.
    *
    * @param sampleRate indicates the sampling rate, in seconds, that
    *        this missioning device should log samples.
    * @param missionStartDelay indicates the amount of time, in seconds,
    *        that should pass before the mission begins.
    * @param rolloverEnabled if <code>false</code>, this device will stop
    *        recording new samples after the data log is full.  Otherwise,
    *        it will replace samples starting at the beginning.
    * @param syncClock if <code>true</code>, the real-time clock of this
    *        missioning device will be synchronized with the current time
    *        according to this <code>java.util.Date</code>.
    */
   public void startNewMission(int sampleRate, int missionStartDelay, boolean rolloverEnabled, boolean syncClock, BooleanArray channelEnabled)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).startNewMission(sampleRate, missionStartDelay, rolloverEnabled, syncClock, channelEnabled.array);
   }

   /**
    * Loads the results of the currently running mission.  Must be called
    * before all mission result/status methods.
    */
   public synchronized void loadMissionResults()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).loadMissionResults();
   }

   /**
    * Returns true if the mission results have been loaded from the device.
    *
    * @return <code>true</code> if the mission results have been loaded.
    */
   public boolean isMissionLoaded()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isMissionLoaded();
   }

   /**
    * Gets the number of channels supported by this Missioning device.
    * Channel specific methods will use a channel number specified
    * by an integer from [0 to (<code>getNumberOfMissionChannels()</code> - 1)].
    *
    * @return the number of channels
    */
   public int getNumberMissionChannels()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getNumberMissionChannels();
   }

   /**
    * Enables/disables the specified mission channel, indicating whether or
    * not the channel's readings will be recorded in the mission log.
    *
    * @param channel the channel to enable/disable
    * @param enable if true, the channel is enabled
    */
   public void setMissionChannelEnable(int channel, boolean enable)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setMissionChannelEnable(channel, enable);
   }

   /**
    * Enables/disables the specified mission channel, indicating whether or
    * not the channel's readings will be recorded in the mission log.
    *
    * @param channel the channel to enable/disable
    * @param enable if true, the channel is enabled
    * @param state the state as returned from readDevice, for cached writes
    */
   public void setMissionChannelEnable(int channel, boolean enable, ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setMissionChannelEnable(channel, enable, state.array);
   }

   /**
    * Returns true if the specified mission channel is enabled, indicating
    * that the channel's readings will be recorded in the mission log.
    *
    * @param channel the channel to enable/disable
    * @param enable if true, the channel is enabled
    */
   public boolean getMissionChannelEnable(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionChannelEnable(channel);
   }

   /**
    * Returns true if the specified mission channel is enabled, indicating
    * that the channel's readings will be recorded in the mission log.
    *
    * @param channel the channel to enable/disable
    * @param enable if true, the channel is enabled
    */
   public boolean getMissionChannelEnable(int channel, ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionChannelEnable(channel, state.array);
   }

   /**
    * Returns the amount of time, in seconds, between samples taken
    * by this missioning device.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return time, in seconds, between sampling
    */
   public int getMissionSampleRate(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionSampleRate(channel);
   }

   /**
    * Returns the number of samples available for the specified channel
    * during the current mission.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return number of samples available for the specified channel
    */
   public int getMissionSampleCount(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionSampleCount(channel);
   }

   /**
    * Reads the device and returns the total number of samples logged
    * since the first power-on of this device.
    *
    * @return the total number of samples logged since the first power-on
    * of this device.
    */
   public int getDeviceSampleCount()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getDeviceSampleCount();
   }

   /**
    * Returns the total number of samples logged since the first power-on
    * of this device.
    *
    * @param state The current state of the device as return from <code>readDevice()</code>
    * @return the total number of samples logged since the first power-on
    * of this device.
    */
   public int getDeviceSampleCount(ByteArray state)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getDeviceSampleCount(state.array);
   }

   /**
    * Returns the total number of samples taken for the specified channel
    * during the current mission.  This number can be more than the actual
    * sample count if rollover is enabled and the log has been filled.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return number of samples taken for the specified channel
    */
   public int getMissionSampleCountTotal(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionSampleCountTotal(channel);
   }

   /**
    * Returns the sample as degrees celsius if temperature channel is specified
    * or as percent relative humidity if data channel is specified.  If the
    * device is a DS2422 configuration (or A-D results are forced on the DS1923),
    * the data channel will return samples as the voltage measured.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param sampleNum the sample number to return, between <code>0</code> and
    *        <code>(getMissionSampleCount(channel)-1)</code>
    * @return the sample's value in degrees Celsius or percent RH.
    */
   public double getMissionSample(int channel, int sampleNum)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionSample(channel, sampleNum);
   }

   /**
    * Returns the sample as an integer value.  This value is not converted to
    * degrees Celsius for temperature or to percent RH for Humidity.  It is
    * simply the 8 or 16 bits of digital data written in the mission log for
    * this sample entry.  It is up to the user to mask off the unused bits
    * and convert this value to it's proper units.  This method is primarily
    * for users of the DS2422 who are using an input device which is not an
    * A-D or have an A-D wholly dissimilar to the one specified in the
    * datasheet.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param sampleNum the sample number to return, between <code>0</code> and
    *        <code>(getMissionSampleCount(channel)-1)</code>
    * @return the sample as a whole integer
    */
   public int getMissionSampleAsInteger(int channel, int sampleNum)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionSampleAsInteger(channel, sampleNum);
   }

   /**
    * Returns the time, in milliseconds, that each sample was taken by the
    * current mission.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param sampleNum the sample number to return, between <code>0</code> and
    *        <code>(getMissionSampleCount(channel)-1)</code>
    * @return the sample's timestamp, in milliseconds
    */
   public String getMissionSampleTimeStamp(int channel, int sampleNum)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionSampleTimeStamp(channel, sampleNum);
   }

   /**
    * Returns <code>true</code> if a mission is currently running.
    * @return <code>true</code> if a mission is currently running.
    */
   public boolean isMissionRunning()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isMissionRunning();
   }

   /**
    * Returns <code>true</code> if a rollover is enabled.
    * @return <code>true</code> if a rollover is enabled.
    */
   public boolean isMissionRolloverEnabled()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isMissionRolloverEnabled();
   }

   /**
    * Returns <code>true</code> if a mission has rolled over.
    * @return <code>true</code> if a mission has rolled over.
    */
   public boolean hasMissionRolloverOccurred()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasMissionRolloverOccurred();
   }

   /**
    * Clears the mission results and erases the log memory from this
    * missioning device.
    */
   public void clearMissionResults()
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).clearMissionResults();
   }

   /**
    * Returns the time, in milliseconds, that the mission began.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return time, in milliseconds, that the mission began
    */
   public String getMissionTimeStamp(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionTimeStamp(channel);
   }

   /**
    * Returns the amount of time, in milliseconds, before the first sample
    * occurred.  If rollover disabled, or datalog didn't fill up, this
    * will be 0.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return time, in milliseconds, before first sample occurred
    */
   public String getFirstSampleOffset(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getFirstSampleOffset(channel);
   }

   /**
    * Returns all available resolutions for the specified mission channel.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return all available resolutions for the specified mission channel.
    */
   public DoubleArray getMissionResolutions(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionResolutions(channel));
   }

   /**
    * Returns the currently selected resolution for the specified
    * channel.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return the currently selected resolution for the specified channel.
    */
   public double getMissionResolution(int channel)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionResolution(channel);
   }

   /**
    * Sets the selected resolution for the specified channel.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param resolution the new resolution for the specified channel.
    */
   public void setMissionResolution(int channel, double resolution)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setMissionResolution(channel, resolution);
   }

   /**
    * Enables/Disables the usage of calibration registers.  Only
    * applies to the DS1923 configuration.  The calibration depends
    * on an average error at 3 known reference points.  This average
    * error is written to 3 registers on the DS1922.  The container
    * use these values to calibrate the recorded humidity values
    * and improve the accuracy of the device.  This method allows you
    * to turn off calibration so that you may download the actual
    * data recorded to the device's memory and perform a manual
    * calibration.
    *
    * @param use if <code>true</code>, all humidity values read from
    *        device will be calibrated.
    *
    */
   public void setTemperatureCalibrationRegisterUsage(boolean use)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setTemperatureCalibrationRegisterUsage(use);
   }

   /**
    * Enables/Disables the usage of the humidity calibration registers.
    * Only applies to the DS1923 configuration.  The calibration depends
    * on an average error at 3 known reference points.  This average
    * error is written to 3 registers on the DS1922.  The container
    * use these values to calibrate the recorded humidity values
    * and improve the accuracy of the device.  This method allows you
    * to turn off calibration so that you may download the actual
    * data recorded to the device's memory and perform a manual
    * calibration.
    *
    * @param use if <code>true</code>, all humidity values read from
    *        device will be calibrated.
    */
   public void setHumidityCalibrationRegisterUsage(boolean use)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setHumidityCalibrationRegisterUsage(use);
   }

   /**
    * Enables/Disables the usage of temperature compensation.  Only
    * applies to the DS1923 configuration.  The temperature
    * compensation adjusts the humidity values based on the known
    * effects of temperature on the humidity sensor.  If this is
    * a joint humidity and temperature mission, the temperature
    * values used could (should?) come from the temperature log
    * itself.  If, however, there is no temperature log the
    * default temperature value can be set for the mission using
    * the <code>setDefaultTemperatureCompensationValue</code> method.
    *
    * @param use if <code>true</code>, all humidity values read from
    *        device will be compensated for temperature.
    *
    * @see #setDefaultTemperatureCompensationValue
    */
   public void setTemperatureCompensationUsage(boolean use)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setTemperatureCompensationUsage(use);
   }

   /**
    * Sets the default temperature value for temperature compensation.  This
    * value will be used if there is no temperature log data or if the
    * <code>override</code> parameter is true.
    *
    * @param temperatureValue the default temperature value for temperature
    *        compensation.
    * @param override if <code>true</code>, the default temperature value
    *        will always be used (instead of the temperature log data).
    *
    * @see #setDefaultTemperatureCompensationValue
    */
   public void setDefaultTemperatureCompensationValue(double temperatureValue, boolean override)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setDefaultTemperatureCompensationValue(temperatureValue, override);
   }

   /**
    * Indicates whether or not the specified channel of this missioning device
    * has mission alarm capabilities.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @return true if the device has mission alarms for the specified channel.
    */
   public boolean hasMissionAlarms(int channel)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasMissionAlarms(channel);
   }

   /**
    * Returns true if the specified channel's alarm value of the specified
    * type has been triggered during the mission.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @return true if the alarm was triggered.
    */
   public boolean hasMissionAlarmed(int channel, int alarmType)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasMissionAlarmed(channel, alarmType);
   }

   /**
    * Returns true if the alarm of the specified type has been enabled for
    * the specified channel.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param  alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @return true if the alarm of the specified type has been enabled for
    *         the specified channel.
    */
   public boolean getMissionAlarmEnable(int channel, int alarmType)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionAlarmEnable(channel, alarmType);
   }

   /**
    * Enables/disables the alarm of the specified type for the specified channel
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param enable if true, alarm is enabled.
    */
   public void setMissionAlarmEnable(int channel, int alarmType, boolean enable)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setMissionAlarmEnable(channel, alarmType, enable);
   }

   /**
    * Returns the threshold value which will trigger the alarm of the
    * specified type on the specified channel.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @return the threshold value which will trigger the alarm
    */
   public double getMissionAlarm(int channel, int alarmType)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMissionAlarm(channel, alarmType);
   }

   /**
    * Sets the threshold value which will trigger the alarm of the
    * specified type on the specified channel.
    *
    * @param channel the mission channel, between <code>0</code> and
    *        <code>(getNumberOfMissionChannels()-1)</code>
    * @param alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param threshold the threshold value which will trigger the alarm
    */
   public void setMissionAlarm(int channel, int alarmType, double threshold)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setMissionAlarm(channel, alarmType, threshold);
   }

   /**
    * Checks to see if this temperature measuring device has high/low
    * trip alarms.
    *
    * @return <code>true</code> if this <code>TemperatureContainer</code>
    *         has high/low trip alarms
    *
    * @see    #getTemperatureAlarm
    * @see    #setTemperatureAlarm
    */
   public boolean hasTemperatureAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasTemperatureAlarms();
   }

   /**
    * Checks to see if this device has selectable temperature resolution.
    *
    * @return <code>true</code> if this <code>TemperatureContainer</code>
    *         has selectable temperature resolution
    *
    * @see    #getTemperatureResolution
    * @see    #getTemperatureResolutions
    * @see    #setTemperatureResolution
    */
   public boolean hasSelectableTemperatureResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasSelectableTemperatureResolution();
   }

   /**
    * Get an array of available temperature resolutions in Celsius.
    *
    * @return byte array of available temperature resolutions in Celsius with
    *         minimum resolution as the first element and maximum resolution
    *         as the last element
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolution
    * @see    #setTemperatureResolution
    */
   public DoubleArray getTemperatureResolutions()
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getTemperatureResolutions());
   }

   /**
    * Gets the temperature alarm resolution in Celsius.
    *
    * @return temperature alarm resolution in Celsius for this 1-wire device
    *
    * @see    #hasTemperatureAlarms
    * @see    #getTemperatureAlarm
    * @see    #setTemperatureAlarm
    *
    */
   public double getTemperatureAlarmResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getTemperatureAlarmResolution();
   }

   /**
    * Gets the maximum temperature in Celsius.
    *
    * @return maximum temperature in Celsius for this 1-wire device
    *
    * @see #getMinTemperature()
    */
   public double getMaxTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMaxTemperature();
   }

   /**
    * Gets the minimum temperature in Celsius.
    *
    * @return minimum temperature in Celsius for this 1-wire device
    *
    * @see #getMaxTemperature()
    */
   public double getMinTemperature()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getMinTemperature();
   }

   /**
    * Performs a temperature conversion.  Use the <code>state</code>
    * information to calculate the conversion time.
    *
    * @param  state byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         In the case of the DS1922 Thermocron, this could also be due to a
    *         currently running mission.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void doTemperatureConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).doTemperatureConvert(state.array);
   }

   /**
    * Gets the temperature value in Celsius from the <code>state</code>
    * data retrieved from the <code>readDevice()</code> method.
    *
    * @param  state byte array with device state information
    *
    * @return temperature in Celsius from the last
    *                     <code>doTemperatureConvert()</code>
    */
   public double getTemperature(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getTemperature(state.array);
   }

   /**
    * Gets the specified temperature alarm value in Celsius from the
    * <code>state</code> data retrieved from the
    * <code>readDevice()</code> method.
    *
    * @param  alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param  state     byte array with device state information
    *
    * @return temperature alarm trip values in Celsius for this 1-wire device
    *
    * @see    #hasTemperatureAlarms
    * @see    #setTemperatureAlarm
    */
   public double getTemperatureAlarm(int alarmType, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getTemperatureAlarm(alarmType, state.array);
   }

   /**
    * Gets the current temperature resolution in Celsius from the
    * <code>state</code> data retrieved from the <code>readDevice()</code>
    * method.
    *
    * @param  state byte array with device state information
    *
    * @return temperature resolution in Celsius for this 1-wire device
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolutions
    * @see    #setTemperatureResolution
    */
   public double getTemperatureResolution(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getTemperatureResolution(state.array);
   }

   /**
    * Sets the temperature alarm value in Celsius in the provided
    * <code>state</code> data.
    * Use the method <code>writeDevice()</code> with
    * this data to finalize the change to the device.
    *
    * @param  alarmType  valid value: <code>ALARM_HIGH</code> or
    *                    <code>ALARM_LOW</code>
    * @param  alarmValue alarm trip value in Celsius
    * @param  state      byte array with device state information
    *
    * @see    #hasTemperatureAlarms
    * @see    #getTemperatureAlarm
    */
   public void setTemperatureAlarm(int alarmType, double alarmValue, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setTemperatureAlarm(alarmType, alarmValue, state.array);
   }

   /**
    * Sets the current temperature resolution in Celsius in the provided
    * <code>state</code> data.   Use the method <code>writeDevice()</code>
    * with this data to finalize the change to the device.
    *
    * @param  resolution temperature resolution in Celsius
    * @param  state      byte array with device state information
    *
    * @throws OneWireException if the device does not support
    * selectable temperature resolution
    *
    * @see    #hasSelectableTemperatureResolution
    * @see    #getTemperatureResolution
    * @see    #getTemperatureResolutions
    */
   public void setTemperatureResolution(double resolution, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setTemperatureResolution(resolution, state.array);
   }

   /**
    * Checks to see if humidity value given is a 'relative' humidity value.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         provides a relative humidity reading
    *
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public boolean isRelative()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isRelative();
   }

   /**
    * Checks to see if this Humidity measuring device has high/low
    * trip alarms.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         has high/low trip alarms
    *
    * @see    #getHumidityAlarm
    * @see    #setHumidityAlarm
    */
   public boolean hasHumidityAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasHumidityAlarms();
   }

   /**
    * Checks to see if this device has selectable Humidity resolution.
    *
    * @return <code>true</code> if this <code>HumidityContainer</code>
    *         has selectable Humidity resolution
    *
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public boolean hasSelectableHumidityResolution()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasSelectableHumidityResolution();
   }

   /**
    * Get an array of available Humidity resolutions in percent humidity (0 to 100).
    *
    * @return byte array of available Humidity resolutions in percent with
    *         minimum resolution as the first element and maximum resolution
    *         as the last element.
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #setHumidityResolution
    */
   public DoubleArray getHumidityResolutions()
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getHumidityResolutions());
   }

   /**
    * Gets the Humidity alarm resolution in percent.
    *
    * @return Humidity alarm resolution in percent for this 1-wire device
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #getHumidityAlarm
    * @see    #setHumidityAlarm
    *
    */
   public double getHumidityAlarmResolution()
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getHumidityAlarmResolution();
   }

   /**
    * Performs a Humidity conversion.
    *
    * @param  state byte array with device state information
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         reading an incorrect CRC from a 1-Wire device.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    * @throws OneWireException on a communication or setup error with the 1-Wire
    *         adapter
    */
   public void doHumidityConvert(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).doHumidityConvert(state.array);
   }

   /**
    * Gets the humidity expressed as a percent value (0.0 to 100.0) of humidity.
    *
    * @param  state byte array with device state information
    * @return humidity expressed as a percent
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #setHumidityResolution
    */
   public double getHumidity(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getHumidity(state.array);
   }

   /**
    * Gets the current Humidity resolution in percent from the
    * <code>state</code> data retrieved from the <code>readDevice()</code>
    * method.
    *
    * @param  state byte array with device state information
    *
    * @return Humidity resolution in percent for this 1-wire device
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolutions
    * @see    #setHumidityResolution
    */
   public double getHumidityResolution(ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getHumidityResolution(state.array);
   }

   /**
    * Gets the specified Humidity alarm value in percent from the
    * <code>state</code> data retrieved from the
    * <code>readDevice()</code> method.
    *
    * @param  alarmType valid value: <code>ALARM_HIGH</code> or
    *                   <code>ALARM_LOW</code>
    * @param  state     byte array with device state information
    *
    * @return Humidity alarm trip values in percent for this 1-wire device
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #setHumidityAlarm
    */
   public double getHumidityAlarm(int alarmType, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getHumidityAlarm(alarmType, state.array);
   }

   /**
    * Sets the Humidity alarm value in percent in the provided
    * <code>state</code> data.
    * Use the method <code>writeDevice()</code> with
    * this data to finalize the change to the device.
    *
    * @param  alarmType  valid value: <code>ALARM_HIGH</code> or
    *                    <code>ALARM_LOW</code>
    * @param  alarmValue alarm trip value in percent
    * @param  state      byte array with device state information
    *
    * @throws OneWireException         Device does not support Humidity
    *                                  alarms
    *
    * @see    #hasHumidityAlarms
    * @see    #getHumidityAlarm
    */
   public void setHumidityAlarm(int alarmType, double alarmValue, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setHumidityAlarm(alarmType, alarmValue, state.array);
   }

   /**
    * Sets the current Humidity resolution in percent in the provided
    * <code>state</code> data.   Use the method <code>writeDevice()</code>
    * with this data to finalize the change to the device.
    *
    * @param  resolution Humidity resolution in percent
    * @param  state      byte array with device state information
    *
    * @throws OneWireException         Device does not support selectable
    *                                  Humidity resolution
    *
    * @see    #hasSelectableHumidityResolution
    * @see    #getHumidityResolution
    * @see    #getHumidityResolutions
    */
   public void setHumidityResolution(double resolution, ByteArray state)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setHumidityResolution(resolution, state.array);
   }

   /**
    * Gets the number of channels supported by this A/D.
    * Channel specific methods will use a channel number specified
    * by an integer from [0 to (<code>getNumberADChannels()</code> - 1)].
    *
    * @return the number of channels
    */
   public int getNumberADChannels()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getNumberADChannels();
   }

   /**
    * Checks to see if this A/D measuring device has high/low
    * alarms.
    *
    * @return true if this device has high/low trip alarms
    */
   public boolean hasADAlarms()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasADAlarms();
   }

   /**
    * Gets an array of available ranges for the specified
    * A/D channel.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    *
    * @return array indicating the available ranges starting
    *         from the largest range to the smallest range
    *
    * @see #getNumberADChannels()
    */
   public DoubleArray getADRanges(int channel)
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADRanges(channel));
   }

   /**
    * Gets an array of available resolutions based
    * on the specified range on the specified A/D channel.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param range A/D range setting from the <code>getADRanges(int)</code> method
    *
    * @return array indicating the available resolutions on this
    *         <code>channel</code> for this <code>range</code>
    *
    * @see #getNumberADChannels()
    * @see #getADRanges(int)
    */
   public DoubleArray getADResolutions(int channel, double range)
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADResolutions(channel, range));
   }

   /**
    * Checks to see if this A/D supports doing multiple voltage
    * conversions at the same time.
    *
    * @return true if the device can do multi-channel voltage reads
    *
    * @see #doADConvert(boolean[],byte[])
    */
   public boolean canADMultiChannelRead()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).canADMultiChannelRead();
   }

   /**
    * Performs a voltage conversion on one specified channel.
    * Use the method <code>getADVoltage(int,byte[])</code> to read
    * the result of this conversion, using the same <code>channel</code>
    * argument as this method uses.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         no 1-Wire device present.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         This is usually a recoverable error.
    * @throws OneWireException on a communication or setup error with the
    *         1-Wire adapter.  This is usually a non-recoverable error.
    *
    * @see OneWireSensor#readDevice()
    * @see #getADVoltage(int,byte[])
    */
   public void doADConvert(int a0, ByteArray a1)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).doADConvert(a0, a1.array);
   }

   /**
    * Performs voltage conversion on one or more specified
    * channels.  The method <code>getADVoltage(byte[])</code> can be used to read the result
    * of the conversion(s). This A/D must support multi-channel read,
    * reported by <code>canADMultiChannelRead()</code>, if more then 1 channel is specified.
    *
    * @param doConvert array of size <code>getNumberADChannels()</code> representing
    *                  which channels should perform conversions
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         no 1-Wire device present.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         This is usually a recoverable error.
    * @throws OneWireException on a communication or setup error with the
    *         1-Wire adapter.  This is usually a non-recoverable error.
    *
    * @see OneWireSensor#readDevice()
    * @see #getADVoltage(byte[])
    * @see #canADMultiChannelRead()
    */
   public void doADConvertMulti(BooleanArray a0, ByteArray a1)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).doADConvert(a0.array, a1.array);
   }

   /**
    * Reads the value of the voltages after a <code>doADConvert(boolean[],byte[])</code>
    * method call.  This A/D device must support multi-channel reading, reported by
    * <code>canADMultiChannelRead()</code>, if more than 1 channel conversion was attempted
    * by <code>doADConvert()</code>.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return array with the voltage values for all channels
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         no 1-Wire device present.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         This is usually a recoverable error.
    * @throws OneWireException on a communication or setup error with the
    *         1-Wire adapter.  This is usually a non-recoverable error.
    *
    * @see #doADConvert(boolean[],byte[])
    */
   public DoubleArray getADVoltage(ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return new DoubleArray().setupObject(((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADVoltage(state.array));
   }

   /**
    * Reads the value of the voltages after a <code>doADConvert(int,byte[])</code>
    * method call.  If more than one channel has been read it is more
    * efficient to use the <code>getADVoltage(byte[])</code> method that
    * returns all channel voltage values.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the voltage value for the specified channel
    *
    * @throws OneWireIOException on a 1-Wire communication error such as
    *         no 1-Wire device present.  This could be
    *         caused by a physical interruption in the 1-Wire Network due to
    *         shorts or a newly arriving 1-Wire device issuing a 'presence pulse'.
    *         This is usually a recoverable error.
    * @throws OneWireException on a communication or setup error with the
    *         1-Wire adapter.  This is usually a non-recoverable error.
    *
    * @see #doADConvert(int,byte[])
    * @see #getADVoltage(byte[])
    */
   public double getADVoltage(int channel, ByteArray state)
      throws com.dalsemi.onewire.adapter.OneWireIOException, com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADVoltage(channel, state.array);
   }

   /**
    * Reads the value of the specified A/D alarm on the specified channel.
    * Not all A/D devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasADAlarms()</code> method.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param alarmType the desired alarm, <code>ALARM_HIGH</code> or <code>ALARM_LOW</code>
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the alarm value in volts
    *
    * @throws OneWireException if this device does not have A/D alarms
    *
    * @see OneWireSensor#readDevice()
    * @see #hasADAlarms()
    */
   public double getADAlarm(int a0, int a1, ByteArray a2)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADAlarm(a0, a1, a2.array);
   }

   /**
    * Checks to see if the specified alarm on the specified channel is enabled.
    * Not all A/D devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasADAlarms()</code> method.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param alarmType the desired alarm, <code>ALARM_HIGH</code> or <code>ALARM_LOW</code>
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if specified alarm is enabled
    *
    * @throws OneWireException if this device does not have A/D alarms
    *
    * @see OneWireSensor#readDevice()
    * @see #hasADAlarms()
    */
   public boolean getADAlarmEnable(int a0, int a1, ByteArray a2)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADAlarmEnable(a0, a1, a2.array);
   }

   /**
    * Checks the state of the specified alarm on the specified channel.
    * Not all A/D devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasADAlarms()</code> method.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param alarmType the desired alarm, <code>ALARM_HIGH</code> or <code>ALARM_LOW</code>
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if specified alarm occurred
    *
    * @throws OneWireException if this device does not have A/D alarms
    *
    * @see OneWireSensor#readDevice()
    * @see #hasADAlarms()
    * @see #getADAlarmEnable(int,int,byte[])
    * @see #setADAlarmEnable(int,int,boolean,byte[])
    */
   public boolean hasADAlarmed(int a0, int a1, ByteArray a2)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasADAlarmed(a0, a1, a2.array);
   }

   /**
    * Returns the currently selected resolution for the specified
    * channel.  This device may not have selectable resolutions,
    * though this method will return a valid value.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the current resolution of <code>channel</code> in volts
    *
    * @see #getADResolutions(int,double)
    * @see #setADResolution(int,double,byte[])
    */
   public double getADResolution(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADResolution(channel, state.array);
   }

   /**
    * Returns the currently selected range for the specified
    * channel.  This device may not have selectable ranges,
    * though this method will return a valid value.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the input voltage range
    *
    * @see #getADRanges(int)
    * @see #setADRange(int,double,byte[])
    */
   public double getADRange(int channel, ByteArray state)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADRange(channel, state.array);
   }

   /**
    * Sets the voltage value of the specified alarm on the specified channel.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all A/D devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasADAlarms()</code> method.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param alarmType the desired alarm, <code>ALARM_HIGH</code> or <code>ALARM_LOW</code>
    * @param alarm new alarm value
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if this device does not have A/D alarms
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasADAlarms()
    * @see #getADAlarm(int,int,byte[])
    * @see #getADAlarmEnable(int,int,byte[])
    * @see #setADAlarmEnable(int,int,boolean,byte[])
    * @see #hasADAlarmed(int,int,byte[])
    */
   public void setADAlarm(int a0, int a1, double a2, ByteArray a3)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setADAlarm(a0, a1, a2, a3.array);
   }

   /**
    * Enables or disables the specified alarm on the specified channel.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all A/D devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasADAlarms()</code> method.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param alarmType the desired alarm, <code>ALARM_HIGH</code> or <code>ALARM_LOW</code>
    * @param alarmEnable true to enable the alarm, false to disable
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if this device does not have A/D alarms
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasADAlarms()
    * @see #getADAlarm(int,int,byte[])
    * @see #setADAlarm(int,int,double,byte[])
    * @see #getADAlarmEnable(int,int,byte[])
    * @see #hasADAlarmed(int,int,byte[])
    */
   public void setADAlarmEnable(int a0, int a1, boolean a2, ByteArray a3)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setADAlarmEnable(a0, a1, a2, a3.array);
   }

   /**
    * Sets the conversion resolution value for the specified channel.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all A/D devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasADAlarms()</code> method.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param resolution one of the resolutions returned by <code>getADResolutions(int,double)</code>
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #getADResolutions(int,double)
    * @see #getADResolution(int,byte[])
    *
    */
   public void setADResolution(int channel, double resolution, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setADResolution(channel, resolution, state.array);
   }

   /**
    * Sets the input range for the specified channel.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all A/D devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasADAlarms()</code> method.
    *
    * @param channel channel number in the range [0 to (<code>getNumberADChannels()</code> - 1)]
    * @param range one of the ranges returned by <code>getADRanges(int)</code>
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see #getADRanges(int)
    * @see #getADRange(int,byte[])
    */
   public void setADRange(int channel, double range, ByteArray state)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setADRange(channel, range, state.array);
   }

   /**
    * No documentation available for method 
    */
   public void setADReferenceVoltage(double referenceVoltage)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setADReferenceVoltage(referenceVoltage);
   }

   /**
    * No documentation available for method 
    */
   public double getADReferenceVoltage()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADReferenceVoltage();
   }

   /**
    * No documentation available for method 
    */
   public void setADDeviceBitCount(int bits)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setADDeviceBitCount(bits);
   }

   /**
    * No documentation available for method 
    */
   public int getADDeviceBitCount()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getADDeviceBitCount();
   }

   /**
    * No documentation available for method 
    */
   public void setForceADResults(boolean force)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setForceADResults(force);
   }

   /**
    * No documentation available for method 
    */
   public boolean getForceADResults()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getForceADResults();
   }

   /**
    * Checks to see if the clock has an alarm feature.
    *
    * @return false, since this device does not have clock alarms
    *
    * @see #getClockAlarm(byte[])
    * @see #isClockAlarmEnabled(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean hasClockAlarm()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).hasClockAlarm();
   }

   /**
    * Checks to see if the clock can be disabled.
    *
    * @return true if the clock can be enabled and disabled
    *
    * @see #isClockRunning(byte[])
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean canDisableClock()
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).canDisableClock();
   }

   /**
    * Gets the clock resolution in milliseconds
    *
    * @return the clock resolution in milliseconds
    */
   public String getClockResolution()
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getClockResolution();
   }

   /**
    * Extracts the Real-Time clock value in milliseconds.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return the time represented in this clock in milliseconds since 1970
    *
    * @see OneWireSensor#readDevice()
    * @see #setClock(long,byte[])
    */
   public String getClock(ByteArray a0)
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getClock(a0.array);
   }

   /**
    * Extracts the clock alarm value for the Real-Time clock.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return milliseconds since 1970 that the clock alarm is set to
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public String getClockAlarm(ByteArray a0)
      throws com.dalsemi.onewire.OneWireException
   {      
      return ""+((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).getClockAlarm(a0.array);
   }

   /**
    * Checks if the clock alarm flag has been set.
    * This will occur when the value of the Real-Time
    * clock equals the value of the clock alarm.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if the Real-Time clock is alarming
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean isClockAlarming(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isClockAlarming(a0.array);
   }

   /**
    * Checks if the clock alarm is enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if clock alarm is enabled
    *
    * @see OneWireSensor#readDevice()
    * @see #hasClockAlarm()
    * @see #isClockAlarming(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public boolean isClockAlarmEnabled(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isClockAlarmEnabled(a0.array);
   }

   /**
    * Checks if the device's oscillator is enabled.  The clock
    * will not increment if the clock oscillator is not enabled.
    *
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @return true if the clock is running
    *
    * @see OneWireSensor#readDevice()
    * @see #canDisableClock()
    * @see #setClockRunEnable(boolean,byte[])
    */
   public boolean isClockRunning(ByteArray a0)
   {      
      return ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).isClockRunning(a0.array);
   }

   /**
    * Sets the Real-Time clock.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.
    *
    * @param time new value for the Real-Time clock, in milliseconds
    * since January 1, 1970
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #getClock(byte[])
    */
   public void setClock(String a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setClock(Long.parseLong(a0), a1.array);
   }

   /**
    * Sets the clock alarm.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all clock devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasClockAlarm()</code> method.
    *
    * @param time - new value for the Real-Time clock alarm, in milliseconds
    * since January 1, 1970
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @throws OneWireException if this device does not have clock alarms
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #isClockAlarming(byte[])
    * @see #setClockAlarmEnable(boolean,byte[])
    */
   public void setClockAlarm(String a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setClockAlarm(Long.parseLong(a0), a1.array);
   }

   /**
    * Enables or disables the oscillator, turning the clock 'on' and 'off'.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all clock devices can disable their oscillators.  Check to see if this device can
    * disable its oscillator first by calling the <code>canDisableClock()</code> method.
    *
    * @param runEnable true to enable the clock oscillator
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #canDisableClock()
    * @see #isClockRunning(byte[])
    */
   public void setClockRunEnable(boolean a0, ByteArray a1)
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setClockRunEnable(a0, a1.array);
   }

   /**
    * Enables or disables the clock alarm.
    * The method <code>writeDevice()</code> must be called to finalize
    * changes to the device.  Note that multiple 'set' methods can
    * be called before one call to <code>writeDevice()</code>.  Also note that
    * not all clock devices have alarms.  Check to see if this device has
    * alarms first by calling the <code>hasClockAlarm()</code> method.
    *
    * @param alarmEnable true to enable the clock alarm
    * @param state current state of the device returned from <code>readDevice()</code>
    *
    * @see OneWireSensor#writeDevice(byte[])
    * @see #hasClockAlarm()
    * @see #isClockAlarmEnabled(byte[])
    * @see #getClockAlarm(byte[])
    * @see #setClockAlarm(long,byte[])
    * @see #isClockAlarming(byte[])
    */
   public void setClockAlarmEnable(boolean a0, ByteArray a1)
      throws com.dalsemi.onewire.OneWireException
   {      
      ((com.dalsemi.onewire.container.OneWireContainer41)objectInstance).setClockAlarmEnable(a0, a1.array);
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   OneWireContainer setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.container.OneWireContainer41)o;
      return this;
   }
}
