// COM proxy class, output from FunctionList.js
package owapi;
/**
 * <P>This class implements an account debit application for unsigned SHA
 * Transactions.  Account data is stored on user iButtons with no digital
 * signature (unlike <code>SHADebit</code> which signs the data with a
 * coprocessor iButton).</P>
 *
 * <P>You may be wondering, "Why use a SHA transaction interface for
 * unsigned account data?"  The answer is for increasing transaction times
 * with the DS1961S user iButton.  All data writes to the DS1961S require
 * knowledge of the iButton's unique secret, which prevents tampering with
 * the account data.  Since a data signature on account data is designed
 * for the same purpose, it is removed from this transaction to remove
 * redundancy and achieve better performance with the DS1961S.</P>
 *
 * <P>Due to the nature of the DS1961S/DS2432 (i.e. it's designed as
 * a battery-less EEPROM device for 'touch' environments), it is possible
 * that account data could be corrupted if the writing of the data is
 * interrupted. In fact, it is also possible that if the writing of a single
 * bit is interrupted, that bit could become borderline (i.e. right on
 * the line of being a 1 or a 0, such that the 1-Wire I/O logic reads it as
 * a 1 and the SHA engine reads it as a 0) and could be permanently corrupted.
 * As a workaround to problems of this nature, a double-write scheme is used
 * where the length indicates which record is the actual account balance.<P>
 *
 * <P>The account file consists of the following:
 *  <UL>
 *    <LI> 1 byte: Length of the account file</LI>
 *    <LI> 1 byte: Account data type (dynamic or static)</LI>
 *    <LI> 2 bytes: Account Money Conversion Factor</LI>
 *    <LI> 4 bytes: Don't Care</LI>
 *    <LI> <B>Record A</B>
 *    <LI> 3 bytes: Account Balance</LI>
 *    <LI> 2 bytes: Transaction ID</LI>
 *    <LI> 1 byte: File continuation pointer</LI>
 *    <LI> 2 bytes: CRC16 of 14 bytes seeded with the page number</LI>
 *    <LI> <B>Record B</B>
 *    <LI> 3 bytes: Account Balance</LI>
 *    <LI> 2 bytes: Transaction ID</LI>
 *    <LI> 1 byte: File continuation pointer</LI>
 *    <LI> 2 bytes: CRC16 of 22 bytes seeded with the page number</LI>
 *    <LI> <B>24 bytes Total</B></LI>
 *  </UL></P>
 *
 * <P>If the length of the account file is 13, then the current record is
 * Record A.  If the length of the account file is 21, then the current record
 * is Record B.  When updating the button, first the other record is updated
 * (i.e. if Record A is current, then update Record B with the new balance) and
 * write the new data for that record to the button.  After verifying that
 * the data was written correctly, the file pointer is the updated to point to
 * the new record.  If data corruption occurs at any point in the transaction
 * (and the user doesn't hang around long enough to allow the transaction
 * system a chance to fix it), the next time the user performs a transaction
 * it is possible to discern what the last known good value is.<P>
 *
 * <P>A typical use case for this class might be as follows:
 * <pre>
 *   OneWireContainer18 coprOWC18 = new OneWireContainer18(adapter,address);
 *
 *   //COPR.0 is the filename for coprocessor service data
 *   SHAiButtonCopr copr = new SHAiButtonCopr(coprOWC18,"COPR.0");
 *
 *   //Initial amount for new users is $100, and debit amount is 50 cents
 *   SHATransaction trans = new SHADebitUnsigned(copr, 10000, 50);
 *
 *   OneWireContainer33 owc33 = new OneWireContainer33(adapter, userAddress);
 *
 *   //The following constructor erases all transaction data from the user and
 *   //installs the system authentication secret on the user iButton.
 *   //The second instance of coprocessor is used for write-authorization.  If you're
 *   //not using the system coprocessor for data signing, it can be re-used for this
 *   //purpose.
 *   SHAiButtonUser user = new SHAiButtonUser33(copr, copr, owc33, true, authSecret);
 *
 *   //creates account data on iButton
 *   if(trans.setupTransactionData(user))
 *      System.out.println("Account data installed successfully");
 *   else
 *      System.out.println("Account data installation failed");
 *
 *   //... ... ... ... ... ... ... ... ... ... ... ... ... ... ... ...
 *
 *   //verifies authentication response of user iButton from "challenge"
 *   if(trans.verifyUser(user))
 *   {
 *      System.out.println("User Verified Successfully");
 *
 *      //Checks to see that account balance is greater than zero
 *      if(trans.verifyTransactionData(user))
 *      {
 *         System.out.println("Account Data Verified Successfully");
 *
 *         //performs the debit and writes the new account balance
 *         if(trans.executeTransaction(user))
 *         {
 *            System.out.println("Account debited.");
 *            System.out.println("New Balance: " +
 *               trans.getParameter(SHADebit.USER_BALANCE));
 *         }
 *      }
 *   }
 *
 *   //... ... ... ... ... ... ... ... ... ... ... ... ... ... ... ...
 *
 *   if(trans.getLastError()!=0)
 *   {
 *      System.err.println("Error code: " + trans.getLastError());
 *   }
 * </pre></P>
 *
 * <p>This class makes use of several performance enhancements for TINI.
 * For instance, most methods are <code>synchronized</code> to access instance
 * variable byte arrays rather than creating new byte arrays every time a
 * transaction is performed.  This could hurt performance in multi-threaded
 * applications, but the usefulness of having several threads contending
 * to talk to a single iButton is questionable since the methods in
 * <code>DSPortAdapter</code>
 * <code>beginExclusive(boolean)</code> and <code>endExclusive()</code>
 * should be used.</p>
 *
 * @see SHATransaction
 * @see SHAiButtonCopr
 * @see SHAiButtonUser
 *
 * @version CLSID=86927404-D640-4C08-A651-DB55CE592854 -  1.00
 * @author  SKH
 * @com.register ( clsid=86927404-D640-4C08-A651-DB55CE592854, typelib=5CE02372-121E-4BCE-8774-80FBC36C509E )
 */
public class SHADebitUnsigned
   extends SHATransaction
   implements com.ms.com.IUnknown
{

   //Instance defined in super class: SHATransaction
   //com.dalsemi.onewire.application.sha.SHADebitUnsigned objectInstance  = null;

   /**
    * Default constructor. Does nothing. Use createNewInstance methods to call a specific constructor.
    */
   public SHADebitUnsigned()
   {
   }

   SHADebitUnsigned(com.dalsemi.onewire.application.sha.SHADebitUnsigned o)
   {
      super(o);
   }
   SHADebitUnsigned(java.lang.Object o)
   {
      super((com.dalsemi.onewire.application.sha.SHADebitUnsigned)o);
   }

   public static final int DEBIT_AMOUNT
          = com.dalsemi.onewire.application.sha.SHADebitUnsigned.DEBIT_AMOUNT;

   public static final int INITIAL_AMOUNT
          = com.dalsemi.onewire.application.sha.SHADebitUnsigned.INITIAL_AMOUNT;

   public static final int USER_BALANCE
          = com.dalsemi.onewire.application.sha.SHADebitUnsigned.USER_BALANCE;

   /**
    * SHADebitUnsigned constructor.  <code>copr</code> is the SHAiButtonCopr
    * that is used to perform this transaction.  After saving a
    * reference to the SHA coprocessor, this constructor resets all
    * parameters for this type of transaction to their default values.
    *
    * @param copr The coprocessor used for authentication and data
    *             signing in this transaction.
    */
   public void createNewInstance(SHAiButtonCopr copr)
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHADebitUnsigned(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance));
   }

   /**
    * SHADebitUnsigned constructor.  <code>copr</code> is the SHAiButtonCopr
    * that is used to perform this transaction.  After saving a
    * reference to the SHA coprocessor, this constructor resets all
    * parameters for this type of transaction to their default values.
    *
    * @param copr The coprocessor used for authentication and data
    *             signing in this transaction.
    */
   public void createNewInstance(SHAiButtonCopr copr, int initialAmount, int debitAmount)
   {      
      objectInstance = new com.dalsemi.onewire.application.sha.SHADebitUnsigned(((com.dalsemi.onewire.application.sha.SHAiButtonCopr)copr.objectInstance), initialAmount, debitAmount);
   }

   /**
    * <P>Verifies user's authentication response.  User is "authenticated" if
    * and only if the digital signature generated the user iButton matches
    * the digital signature generated by the coprocessor after the user's
    * unique secret has been recreated on the coprocessor.</P>
    *
    * <P><B>Flow of action: </B>
    *   <ul>
    *     <li> Generate 3-byte "challenge" on coprocessor </li>
    *     <li> Write challenge to scratchpad of user </li>
    *     <li> Read account data page with signature </li>
    *     <li> Attempt to match user's signature with the coprocessor </li>
    *   </ul></P>
    *
    * @param user SHAiButtonUser upon which the transaction occurs.
    *
    * @see SHAiButtonCopr#generateChallenge(int,byte[],int)
    * @see SHAiButtonCopr#verifyAuthentication(byte[],byte[],byte[],byte[],byte)
    * @see SHAiButtonUser#readAccountData(byte[],int,byte[],int,byte[],int)
    * @see #getLastError()
    */
   public synchronized boolean verifyUser(SHAiButtonUser user)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebitUnsigned)objectInstance).verifyUser(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance));
   }

   /**
    * <P>Verifies user's account data.  Account data is "verified" if and
    * only if the account balance is greater than zero.  No digital
    * signature is checked by this transaction.</P>
    *
    * <P><B>Flow of action: </B>
    *   <ul>
    *     <li> Read the account data from user </li>
    *     <li> Extract account balance </li>
    *     <li> Debit money from balance </li>
    *     <li> Insert the new balance </li>
    *     <li> Write the account data to the user </li>
    *   </ul></P>
    *
    * <P>If previous steps have been executed, all "Read" commands on
    * the user are reading from cached data.</P>
    *
    * @param user SHAiButtonUser upon which the transaction occurs.
    *
    * @return <code>true</code> if and only if the account balance is
    * greater than zero.
    *
    * @see SHAiButtonUser#readAccountData(byte[],int)
    * @see #getLastError()
    */
   public synchronized boolean verifyTransactionData(SHAiButtonUser user)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebitUnsigned)objectInstance).verifyTransactionData(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance));
   }

   /**
    * <P>Performs the unsigned debit, subtracting the debit amount from
    * the user's balance and storing the new, unsigned account data on the
    * user's iButton.  The debit amount can be set using
    * <code>transaction.setParameter(SHADebit.DEBIT_AMOUNT, 50)</code>,
    * where the value is in units of cents (i.e. for 1 dollar, use 100).</P>
    *
    * <P><B>Flow of action: </B>
    *   <ul>
    *     <li> Read the account data from user </li>
    *     <li> Extract account balance </li>
    *     <li> Assert balance greater than debit amount </li>
    *     <li> Debit money from balance </li>
    *     <li> Insert the new balance </li>
    *     <li> Write the account data to the user </li>
    *   </ul></P>
    *
    * <P>If previous steps have been executed, all "Read" commands on
    * the user are reading from cached data.</P>
    *
    * @param user SHAiButtonUser upon which the transaction occurs.
    *
    * @return <code>true</code> if and only if the user has enough in the
    * account balance to perform the requested debit AND the account data
    * has been written to the button.
    *
    * @see SHAiButtonUser#readAccountData(byte[],int)
    * @see SHAiButtonUser#writeAccountData(byte[],int)
    * @see #getLastError()
    */
   public synchronized boolean executeTransaction(SHAiButtonUser user, boolean verifySuccess)
      throws com.dalsemi.onewire.OneWireException, com.dalsemi.onewire.adapter.OneWireIOException
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebitUnsigned)objectInstance).executeTransaction(((com.dalsemi.onewire.application.sha.SHAiButtonUser)user.objectInstance), verifySuccess);
   }

   /**
    * <P>Retrieves the value of a particular parameter for this
    * debit transaction.</P>
    *
    * <P><B>Valid Parameters</B>
    *   <UL>
    *     <LI><code>SHADebit.DEBIT_AMOUNT</code></LI>
    *     <LI><code>SHADebit.INITIAL_AMOUNT</code></LI>
    *     <LI><code>SHADebit.USER_BALANCE</code></LI>
    *   </UL>
    * </P>
    *
    * <P>Note that the value of <code>SHADebit.USER_BALANCE</code> will
    * be set after calling <code>verifyTransactionData(SHAiButtonUser)</code>
    * and  after calling <code>executeTransaction(SHAiButtonUser)</code>.</P>
    *
    * @return The value of the requested parameter.
    *
    * @throws IllegalArgumentException if an invalid parameter type
    *         is requested.
    */
   public synchronized int getParameter(int type)
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebitUnsigned)objectInstance).getParameter(type);
   }

   /**
    * <P>Sets the value of a particular parameter for this
    * debit transaction.</P>
    *
    * <P><B>Valid Parameters</B>
    *   <UL>
    *     <LI><code>SHADebit.DEBIT_AMOUNT</code></LI>
    *     <LI><code>SHADebit.INITIAL_AMOUNT</code></LI>
    *   </UL>
    * </P>
    *
    * @param type Specifies the parameter type (<code>SHADebit.DEBIT_AMOUNT</code> or
    *        <code>SHADebit.INITIAL_AMOUNT</code>)
    * @return </code>true</code> if a valid parameter type was specified
    *         and the value of the parameter is positive.
    *
    * @throws IllegalArgumentException if an invalid parameter type
    *         is requested.
    */
   public synchronized boolean setParameter(int type, int param)
   {      
      return ((com.dalsemi.onewire.application.sha.SHADebitUnsigned)objectInstance).setParameter(type, param);
   }

   /**
    * <p>Resets all transaction parameters to default values</p>
    */
   public synchronized void resetParameters()
   {      
      ((com.dalsemi.onewire.application.sha.SHADebitUnsigned)objectInstance).resetParameters();
   }



   /** Sets this object's reference to null */
   public void freeObject()
   {
      this.objectInstance = null;
   }

   /** Returns true if this COM Stub class refers to an object which is not null */
   public boolean isObjectInitialized()
   {
      return this.objectInstance != null;
   }

   SHATransaction setupObject(Object o)
   {
      this.objectInstance = (com.dalsemi.onewire.application.sha.SHADebitUnsigned)o;
      return this;
   }
}
